#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

// Структура для зберігання координат точки
struct Point {
    int x, y, index; // координати і індекс точки
};

// Функція для порівняння точок по координатах
bool compare(Point a, Point b) {
    if (a.x == b.x) return a.y < b.y;
    return a.x < b.x;
}

// Перевірка на перетин відрізків
bool isIntersect(Point a1, Point a2, Point b1, Point b2) {
    // Перевірка орієнтацій для двох відрізків (a1, a2) та (b1, b2)
    auto cross = [](Point p1, Point p2, Point p3) {
        return (p2.x - p1.x) * (p3.y - p1.y) - (p2.y - p1.y) * (p3.x - p1.x);
    };
    
    return cross(a1, a2, b1) * cross(a1, a2, b2) < 0 && cross(b1, b2, a1) * cross(b1, b2, a2) < 0;
}

int main() {
    int t; // кількість тестів
    cin >> t;
    
    while (t--) {
        int N; // кількість точок одного кольору
        cin >> N;
        
        vector<Point> blue(N), red(N);
        
        // Зчитуємо координати синіх точок
        for (int i = 0; i < N; i++) {
            cin >> blue[i].x >> blue[i].y;
            blue[i].index = i + 1; // індексуємо сині точки
        }
        
        // Зчитуємо координати червоних точок
        for (int i = 0; i < N; i++) {
            cin >> red[i].x >> red[i].y;
            red[i].index = i + 1; // індексуємо червоні точки
        }
        
        // Сортуємо сині і червоні точки за їх координатами
        sort(blue.begin(), blue.end(), compare);
        sort(red.begin(), red.end(), compare);

        bool valid = true;
        vector<pair<int, int>> result;
        
        // Перевірка чи не перетинаються відрізки
        for (int i = 0; i < N; i++) {
            result.push_back({blue[i].index, red[i].index});
        }
        
        // Тепер перевіряємо перетини
        for (int i = 0; i < N; i++) {
            for (int j = i + 1; j < N; j++) {
                if (isIntersect(blue[i], red[i], blue[j], red[j])) {
                    valid = false;
                    break;
                }
            }
        }

        if (!valid) {
            cout << "0\n"; // Якщо перетин є, то виводимо 0
        } else {
            for (auto& p : result) {
                cout << p.first << " " << p.second << endl;
            }
        }
    }
    
    return 0;
}
