def read_grid(n: int) -> list[list[int]]:
    """Read the color grid from input."""
    return [list(map(int, input().split())) for _ in range(n)]

def is_square(p1: tuple[int, int], p2: tuple[int, int], 
              p3: tuple[int, int], p4: tuple[int, int]) -> bool:
    """Check if four points form a square."""

    def dist2(a, b):
        return (a[0] - b[0])**2 + (a[1] - b[1])**2
    
    distances = [
        dist2(p1, p2), dist2(p1, p3), dist2(p1, p4),
        dist2(p2, p3), dist2(p2, p4),
        dist2(p3, p4)
    ]
    distances.sort()
    
    return (distances[0] > 0 and
            distances[0] == distances[1] == distances[2] == distances[3] and
            distances[4] == distances[5] and
            distances[4] > distances[0])

def count_same_color_squares(n: int, grid: list[list[int]]) -> int:
    """Count squares with vertices of the same color."""
    count = 0
    points = [(i, j) for i in range(n) for j in range(n)]

    for i in range(len(points)):
        for j in range(i + 1, len(points)):
            for k in range(j + 1, len(points)):
                for l in range(k + 1, len(points)):
                    p1, p2, p3, p4 = points[i], points[j], points[k], points[l]
                
                    if is_square(p1, p2, p3, p4):
                       
                        color = grid[p1[0]][p1[1]]
                        if (color == grid[p2[0]][p2[1]] == 
                            grid[p3[0]][p3[1]] == grid[p4[0]][p4[1]]):
                            count += 1
    
    return count

def main():

    n = int(input())
    grid = read_grid(n)
    
    result = count_same_color_squares(n, grid)
    print(result)

if __name__ == "__main__":
    main()
