#include <iostream>
#include <vector>
#include <algorithm>
#include <tuple>

using namespace std;

// Структура для представлення точки
struct Point {
    int x, y, index;
};

// Перевіряє, чи перетинаються два відрізки
bool segmentsIntersect(Point a, Point b, Point c, Point d) {
    auto cross = [](Point p1, Point p2) {
        return p1.x * p2.y - p1.y * p2.x;
    };

    auto subtract = [](Point p1, Point p2) {
        return Point{p1.x - p2.x, p1.y - p2.y, -1};
    };

    Point ab = subtract(b, a);
    Point ac = subtract(c, a);
    Point ad = subtract(d, a);
    Point cd = subtract(d, c);
    Point ca = subtract(a, c);
    Point cb = subtract(b, c);

    int cross1 = cross(ab, ac);
    int cross2 = cross(ab, ad);
    int cross3 = cross(cd, ca);
    int cross4 = cross(cd, cb);

    return (cross1 * cross2 < 0 && cross3 * cross4 < 0);
}

// Основна функція для обробки одного тестового блоку
bool solveTestCase(int N, vector<Point>& blue, vector<Point>& red, vector<pair<int, int>>& result) {
    sort(blue.begin(), blue.end(), [](Point a, Point b) {
        return tie(a.x, a.y) < tie(b.x, b.y);
    });
    sort(red.begin(), red.end(), [](Point a, Point b) {
        return tie(a.x, a.y) < tie(b.x, b.y);
    });

    result.clear();
    for (int i = 0; i < N; i++) {
        result.emplace_back(blue[i].index, red[i].index);
    }

    // Перевірка на перетини
    for (int i = 0; i < N; i++) {
        for (int j = i + 1; j < N; j++) {
            if (segmentsIntersect(blue[i], red[i], blue[j], red[j])) {
                return false;
            }
        }
    }

    return true;
}

int main() {
    int t;
    cin >> t;
    while (t--) {
        int N;
        cin >> N;

        vector<Point> blue(N), red(N);
        for (int i = 0; i < N; i++) {
            cin >> blue[i].x >> blue[i].y;
            blue[i].index = i + 1;
        }
        for (int i = 0; i < N; i++) {
            cin >> red[i].x >> red[i].y;
            red[i].index = i + 1;
        }

        vector<pair<int, int>> result;
        if (solveTestCase(N, blue, red, result)) {
            for (auto& [b, r] : result) {
                cout << b << " " << r << "\n";
            }
        } else {
            cout << 0 << "\n";
        }
    }

    return 0;
}


