#include <iostream>
#include <vector>
#include <algorithm>
#include <tuple>
#include <cmath>

using namespace std;

// Структура для представлення точки
struct Point {
    int x, y, index;
};

// Обчислення крос-продукту
long long crossProduct(Point a, Point b, Point c) {
    return (b.x - a.x) * 1LL * (c.y - a.y) - (b.y - a.y) * 1LL * (c.x - a.x);
}

// Перевірка перетину двох відрізків
bool segmentsIntersect(Point a, Point b, Point c, Point d) {
    return (crossProduct(a, b, c) * crossProduct(a, b, d) < 0 &&
            crossProduct(c, d, a) * crossProduct(c, d, b) < 0);
}

bool solveTestCase(int N, vector<Point>& blue, vector<Point>& red, vector<pair<int, int>>& result) {
    // Сортуємо сині точки для простоти
    sort(blue.begin(), blue.end(), [](Point a, Point b) {
        return tie(a.x, a.y) < tie(b.x, b.y);
    });

    // Сортуємо червоні точки для простоти
    sort(red.begin(), red.end(), [](Point a, Point b) {
        return tie(a.x, a.y) < tie(b.x, b.y);
    });

    // З'єднуємо точки за порядком сортування
    result.clear();
    for (int i = 0; i < N; i++) {
        result.emplace_back(blue[i].index, red[i].index);
    }

    // Перевіряємо на перетини
    for (int i = 0; i < N; i++) {
        for (int j = i + 1; j < N; j++) {
            if (segmentsIntersect(blue[i], red[i], blue[j], red[j])) {
                return false; // Не вдалося побудувати пари без перетинів
            }
        }
    }

    return true; // Успішно побудовані пари
}

int main() {
    int t;
    cin >> t;
    while (t--) {
        int N;
        cin >> N;

        vector<Point> blue(N), red(N);
        for (int i = 0; i < N; i++) {
            cin >> blue[i].x >> blue[i].y;
            blue[i].index = i + 1;
        }
        for (int i = 0; i < N; i++) {
            cin >> red[i].x >> red[i].y;
            red[i].index = i + 1;
        }

        vector<pair<int, int>> result;
        if (solveTestCase(N, blue, red, result)) {
            for (auto& [b, r] : result) {
                cout << b << " " << r << "\n";
            }
        } else {
            cout << 0 << "\n";
        }
    }

    return 0;
}


