#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

// Структура для представлення точки
struct Point {
    int x, y, index;
};

// Функція обчислення векторного добутку
long long crossProduct(Point a, Point b, Point c) {
    return (b.x - a.x) * 1LL * (c.y - a.y) - (b.y - a.y) * 1LL * (c.x - a.x);
}

// Перевірка перетину двох відрізків
bool segmentsIntersect(Point a, Point b, Point c, Point d) {
    long long cp1 = crossProduct(a, b, c) * crossProduct(a, b, d);
    long long cp2 = crossProduct(c, d, a) * crossProduct(c, d, b);

    // Перевірка перетину
    return (cp1 < 0 && cp2 < 0);
}

// Основна функція для побудови пар
bool solve(int N, vector<Point>& blue, vector<Point>& red, vector<pair<int, int>>& result) {
    result.clear();

    // Жадібне з'єднання точок у тому порядку, як вони подані
    for (int i = 0; i < N; i++) {
        result.emplace_back(blue[i].index, red[i].index);
    }

    // Перевіряємо, чи є перетини
    for (int i = 0; i < N; i++) {
        for (int j = i + 1; j < N; j++) {
            // Якщо відрізки перетинаються
            if (segmentsIntersect(blue[i], red[i], blue[j], red[j])) {
                return false; // Якщо є перетин, розв'язок неможливий
            }
        }
    }

    return true;
}

int main() {
    int t;
    cin >> t;

    while (t--) {
        int N;
        cin >> N;

        vector<Point> blue(N), red(N);
        for (int i = 0; i < N; i++) {
            cin >> blue[i].x >> blue[i].y;
            blue[i].index = i + 1;
        }
        for (int i = 0; i < N; i++) {
            cin >> red[i].x >> red[i].y;
            red[i].index = i + 1;
        }

        vector<pair<int, int>> result;
        if (solve(N, blue, red, result)) {
            for (auto& [b, r] : result) {
                cout << b << " " << r << "\n";
            }
        } else {
            cout << 0 << "\n"; // Якщо розв'язок неможливий
        }
    }

    return 0;
}


