#include <iostream>
#include <vector>
#include <algorithm>

struct Point {
    int x, y, index;
    char color;
};

bool compare(const Point& a, const Point& b) {
    if (a.x != b.x) return a.x < b.x;
    return a.y < b.y;
}

bool isIntersecting(Point a, Point b, Point c, Point d) {
    auto cross = [](Point p1, Point p2, Point p3) {
        return (p2.x - p1.x) * (p3.y - p1.y) - (p3.x - p1.x) * (p2.y - p1.y);
    };
    return (cross(a, b, c) * cross(a, b, d) < 0) && (cross(c, d, a) * cross(c, d, b) < 0);
}

int main() {
    int t;
    std::cin >> t;

    while (t--) {
        int N;
        std::cin >> N;

        std::vector<Point> points(2 * N);
        for (int i = 0; i < N; ++i) {
            std::cin >> points[i].x >> points[i].y;
            points[i].index = i + 1;
            points[i].color = 'B';  // Blue
        }

        for (int i = 0; i < N; ++i) {
            std::cin >> points[N + i].x >> points[N + i].y;
            points[N + i].index = i + 1;
            points[N + i].color = 'R';  // Red
        }

        std::sort(points.begin(), points.end(), compare);

        std::vector<std::pair<int, int>> result;
        bool possible = true;

        for (int i = 0; i < N && possible; ++i) {
            bool found = false;
            for (int j = N; j < 2 * N; ++j) {
                if (!isIntersecting(points[i], points[N + i], points[j], points[j + 1])) {
                    result.push_back({points[i].index, points[j].index});
                    found = true;
                    break;
                }
            }
            if (!found) possible = false;
        }

        if (possible) {
            for (const auto& pair : result) {
                std::cout << pair.first << " " << pair.second << std::endl;
            }
        } else {
            std::cout << 0 << std::endl;
        }
    }

    return 0;
}




