def is_intersect(a, b, c, d):
    """
    Перевіряє, чи перетинаються відрізки (a, b) і (c, d).
    """
    def orientation(p, q, r):
        val = (q[1] - p[1]) * (r[0] - q[0]) - (q[0] - p[0]) * (r[1] - q[1])
        if val == 0:
            return 0  # колінеарні
        return 1 if val > 0 else -1  # за чи проти годинникової стрілки

    def on_segment(p, q, r):
        if min(p[0], r[0]) <= q[0] <= max(p[0], r[0]) and min(p[1], r[1]) <= q[1] <= max(p[1], r[1]):
            return True
        return False

    o1 = orientation(a, b, c)
    o2 = orientation(a, b, d)
    o3 = orientation(c, d, a)
    o4 = orientation(c, d, b)

    if o1 != o2 and o3 != o4:
        return True

    if o1 == 0 and on_segment(a, c, b):
        return True
    if o2 == 0 and on_segment(a, d, b):
        return True
    if o3 == 0 and on_segment(c, a, d):
        return True
    if o4 == 0 and on_segment(c, b, d):
        return True

    return False


def solve_test_case(N, blue_points, red_points):
    segments = []
    used_red = [False] * N

    for i, blue in enumerate(blue_points):
        best_red = -1
        best_dist = float('inf')
        for j, red in enumerate(red_points):
            if not used_red[j]:
                dist = (blue[0] - red[0]) ** 2 + (blue[1] - red[1]) ** 2
                if dist < best_dist:
                    best_dist = dist
                    best_red = j
        if best_red == -1:
            return [0]  # Немає доступних червоних точок

        for seg_b, seg_r in segments:
            if is_intersect(blue, red_points[best_red], seg_b, seg_r):
                return [0]  # Перетин знайдено

        segments.append((blue, red_points[best_red]))
        used_red[best_red] = True

    return [(i + 1, j + 1) for i, (b, r) in enumerate(segments)]


def main():
    import sys
    input = sys.stdin.read
    data = input().splitlines()

    t = int(data[0])  # Кількість тестів
    results = []
    idx = 1
    for _ in range(t):
        N = int(data[idx])
        idx += 1
        blue_points = []
        for _ in range(N):
            x, y = map(int, data[idx].split())
            blue_points.append((x, y))
            idx += 1
        red_points = []
        for _ in range(N):
            x, y = map(int, data[idx].split())
            red_points.append((x, y))
            idx += 1
        result = solve_test_case(N, blue_points, red_points)
        results.append(result)

    for result in results:
        if result == [0]:
            print(0)
        else:
            for b, r in result:
                print(b, r)


if __name__ == "__main__":
    main()
