def solve(t, test_cases):
    results = []
    
    def do_segments_intersect(a, b, c, d):
        """Перевіряє, чи перетинаються відрізки (a, b) та (c, d)."""
        def orientation(p, q, r):
            """Визначає орієнтацію трьох точок."""
            val = (q[1] - p[1]) * (r[0] - q[0]) - (q[0] - p[0]) * (r[1] - q[1])
            if val == 0:
                return 0
            return 1 if val > 0 else 2
        
        def on_segment(p, q, r):
            """Чи лежить точка r на відрізку pq."""
            return (min(p[0], q[0]) <= r[0] <= max(p[0], q[0]) and
                    min(p[1], q[1]) <= r[1] <= max(p[1], q[1]))
        
        o1 = orientation(a, b, c)
        o2 = orientation(a, b, d)
        o3 = orientation(c, d, a)
        o4 = orientation(c, d, b)
        
        # Перетинаються, якщо орієнтації різні
        if o1 != o2 and o3 != o4:
            return True
        
        # Чи лежить одна точка на іншому відрізку
        if o1 == 0 and on_segment(a, b, c): return True
        if o2 == 0 and on_segment(a, b, d): return True
        if o3 == 0 and on_segment(c, d, a): return True
        if o4 == 0 and on_segment(c, d, b): return True
        
        return False
    
    for case in test_cases:
        N, blue_points, red_points = case
        pairs = []
        used_blue = set()
        used_red = set()
        segments = []
        
        distances = []
        for i, b in enumerate(blue_points):
            for j, r in enumerate(red_points):
                dist = (b[0] - r[0])**2 + (b[1] - r[1])**2
                distances.append((dist, i + 1, j + 1))  # Зберігаємо відстань та індекси точок
        
        distances.sort()  # Сортуємо за відстанями
        
        for _, blue_idx, red_idx in distances:
            if blue_idx not in used_blue and red_idx not in used_red:
                new_segment = (blue_points[blue_idx - 1], red_points[red_idx - 1])
                conflict = False
                for seg in segments:
                    if do_segments_intersect(seg[0], seg[1], new_segment[0], new_segment[1]):
                        conflict = True
                        break
                if not conflict:
                    pairs.append((blue_idx, red_idx))
                    segments.append(new_segment)
                    used_blue.add(blue_idx)
                    used_red.add(red_idx)
        
        if len(pairs) == N:
            results.append(pairs)
        else:
            results.append([0])
    
    return results

# Введення даних
t = int(input())
test_cases = []
for _ in range(t):
    N = int(input())
    blue_points = [tuple(map(int, input().split())) for _ in range(N)]
    red_points = [tuple(map(int, input().split())) for _ in range(N)]
    test_cases.append((N, blue_points, red_points))

# Розв'язання
answers = solve(t, test_cases)

# Виведення результату
for answer in answers:
    if answer == [0]:
        print(0)
    else:
        for pair in answer:
            print(pair[0], pair[1])
