import math

def rotate_point(x, y, angle):
    """Функція для обертання точки (x, y) на кут angle (в радіанах)."""
    angle_rad = math.radians(angle)
    x_new = x * math.cos(angle_rad) - y * math.sin(angle_rad)
    y_new = x * math.sin(angle_rad) + y * math.cos(angle_rad)
    return (x_new, y_new)

def is_square(corners, grid):
    """Перевірка, чи всі чотири вершини квадрата мають однаковий колір."""
    color = grid[corners[0][0]][corners[0][1]]
    for x, y in corners[1:]:
        if grid[x][y] != color:
            return False
    return True

def count_squares(N, grid):
    count = 0
    
    # Перебираємо всі можливі квадрати розміром від 1x1 до N-1xN-1
    for size in range(1, N):  # Розмір квадрата від 1 до N-1
        for i in range(N - size):
            for j in range(N - size):
                # Створюємо 4 вершини квадрата без обертання
                corners = [
                    (i, j),
                    (i + size, j),
                    (i, j + size),
                    (i + size, j + size)
                ]
                
                # Перевіряємо квадрати без обертання
                if is_square(corners, grid):
                    count += 1
                
                # Тепер перевіряємо квадрат, обернений на 45 градусів (на приклад)
                rotated_corners = [rotate_point(x, y, 45) for x, y in corners]
                # Перевірка, чи всі чотири вершини обернутого квадрата є в межах сітки
                if all(0 <= x < N and 0 <= y < N for x, y in rotated_corners):
                    # Якщо обертання не виходить за межі сітки, перевіряємо кольори
                    rotated_corners = [(round(x), round(y)) for x, y in rotated_corners]
                    if is_square(rotated_corners, grid):
                        count += 1

    return count

# Вхідні дані
N = int(input())  # Розмір квадрата
grid = [list(map(int, input().split())) for _ in range(N)]

# Виведення результату
print(count_squares(N, grid))