def distance(p1, p2):
    return ((p1[0] - p2[0])**2 + (p1[1] - p2[1])**2)**0.5

def solve_matching(blue_points, red_points):
    N = len(blue_points)
    
    # Створюємо матрицю відстаней
    graph = [[distance(blue_points[i], red_points[j]) for j in range(N)] for i in range(N)]
    
    # Угорський алгоритм для знаходження оптимального паросполучення
    used_blue = [False] * N
    used_red = [False] * N
    matching = [0] * N
    
    for blue_idx in range(N):
        # Шукаємо найближчу вільну червону точку
        best_dist = float('inf')
        best_red_idx = -1
        
        for red_idx in range(N):
            if not used_red[red_idx]:
                dist = graph[blue_idx][red_idx]
                if dist < best_dist:
                    best_dist = dist
                    best_red_idx = red_idx
        
        # Якщо не знайшли вільну точку, задача не має розв'язку
        if best_red_idx == -1:
            return None
        
        matching[blue_idx] = best_red_idx + 1
        used_blue[blue_idx] = True
        used_red[best_red_idx] = True
    
    # Перевіряємо, чи не перетинаються відрізки
    for i in range(N):
        for j in range(i+1, N):
            p1 = blue_points[i]
            p2 = red_points[matching[i]-1]
            p3 = blue_points[j]
            p4 = red_points[matching[j]-1]
            
            if do_lines_intersect(p1, p2, p3, p4):
                return None
    
    return matching

def do_lines_intersect(p1, p2, p3, p4):
    def ccw(A, B, C):
        return (C[1]-A[1]) * (B[0]-A[0]) > (B[1]-A[1]) * (C[0]-A[0])
    
    return ccw(p1,p3,p4) != ccw(p2,p3,p4) and ccw(p1,p2,p3) != ccw(p1,p2,p4)

def main():
    t = int(input())
    
    for _ in range(t):
        N = int(input())
        
        # Зчитуємо сині точки
        blue_points = []
        for i in range(N):
            x, y = map(int, input().split())
            blue_points.append((x, y))
        
        # Зчитуємо червоні точки
        red_points = []
        for i in range(N):
            x, y = map(int, input().split())
            red_points.append((x, y))
        
        # Знаходимо розв'язок
        result = solve_matching(blue_points, red_points)
        
        # Виводимо результат
        if result is None:
            print(0)
        else:
            for blue_idx, red_idx in enumerate(result, 1):
                print(blue_idx, red_idx)

if __name__ == "__main__":
    main()