from collections import deque

def can_meet(n: int) -> int:
    """
    Determines if Alice and Bob can meet in the same box and calculates the minimum number of seconds required.

    Parameters:
    - n: int
        The total number of boxes, where Alice starts at box 1 and Bob starts at box n.

    Returns:
    - int:
        The minimum number of seconds required for Alice and Bob to meet in the same box.
        Returns -1 if they cannot meet.
    """

    # Initialize the positions of Alice and Bob
    alice_position = 1
    bob_position = n

    # Initialize a queue for BFS and a set to track visited positions
    queue = deque([(alice_position, bob_position, 0)])  # (Alice's position, Bob's position, seconds)
    visited = set()  # To track visited states

    while queue:
        alice_pos, bob_pos, seconds = queue.popleft()

        # Check if they are in the same box
        if alice_pos == bob_pos:
            return seconds

        # Generate possible moves for Alice
        alice_moves = []
        if alice_pos + 2 <= n:
            alice_moves.append(alice_pos + 2)
        if alice_pos + 3 <= n:
            alice_moves.append(alice_pos + 3)

        # Generate possible moves for Bob
        bob_moves = []
        if bob_pos - 1 >= 1:
            bob_moves.append(bob_pos - 1)
        if bob_pos - 2 >= 1:
            bob_moves.append(bob_pos - 2)

        # Explore all combinations of Alice's and Bob's moves
        for new_alice_pos in alice_moves:
            for new_bob_pos in bob_moves:
                state = (new_alice_pos, new_bob_pos)
                if state not in visited:
                    visited.add(state)
                    queue.append((new_alice_pos, new_bob_pos, seconds + 1))

    # If we exhaust all possibilities and they never meet
    return -1

def main():
    """
    Main function to execute the logic of the teleportation experiment.

    The function prompts the user to input the number of boxes (N) and calls the can_meet function
    to determine if Alice and Bob can meet and the minimum time required.
    """

    # Prompting user to input the number of boxes
    n = int(input("Введіть кількість боксів (2≤N≤1000000000): "))

    # Validating the input to ensure it is within the specified range
    if n < 2 or n > 1000000000:
        raise ValueError("The value of n must be between 2 and 1,000,000,000.")

    # Call the function to determine if they can meet and get the time required
    result = can_meet(n)

    # Output the result
    if result != -1:
        print(f"Аліса та Боб можуть зустрітися через {result} секунд.")
    else:
        print("Аліса та Боб не можуть зустрітися.")

# Execute the main function
if __name__ == "__main__":
    main()