def count_uniform_color_squares(N, grid):
    """
    Counts the number of squares with vertices at integer coordinates within a given N x N grid,
    where all four vertices of the square are of the same color.

    Parameters:
    - N: int
        The size of the grid (the length of the sides of the square).
    - grid: list of list of int
        A 2D list representing the grid where 0 indicates a blue point and 1 indicates a red point.

    Returns:
    - int:
        The total number of squares with vertices of the same color.
    """

    count = 0  # Initialize the count of squares

    # Iterate over all possible top-left corners of squares
    for i in range(N):
        for j in range(N):
            # Iterate over all possible sizes of squares
            for size in range(1, N - max(i, j) + 1):
                # Determine the coordinates of the four corners of the square
                top_left = grid[i][j]
                top_right = grid[i][j + size - 1]
                bottom_left = grid[i + size - 1][j]
                bottom_right = grid[i + size - 1][j + size - 1]

                # Check if all corners are the same color
                if top_left == top_right == bottom_left == bottom_right:
                    count += 1  # Increment the count if they are the same

    return count  # Return the total count of squares


# Example usage of the function:
if __name__ == "__main__":
    # Example input 1
    N1 = 4
    grid1 = [
        [0, 1, 0, 0],
        [0, 0, 1, 1],
        [1, 0, 0, 0],
        [0, 1, 1, 1]
    ]
    result1 = count_uniform_color_squares(N1, grid1)
    print(result1)  # Expected output: 1

    # Example input 2
    N2 = 4
    grid2 = [
        [0, 1, 0, 0],
        [0, 0, 0, 1],
        [1, 0, 0, 0],
        [0, 1, 1, 1]
    ]
    result2 = count_uniform_color_squares(N2, grid2)
    print(result2)  # Expected output: 2