def connect_points(red_points, blue_points):
  """Connects red and blue points with non-intersecting line segments.

  Args:
    red_points: A list of tuples representing red points.
    blue_points: A list of tuples representing blue points.

  Returns:
    A list of pairs (i, j) indicating that the i-th red point is connected to the j-th blue point.
    Returns None if no solution is found.
  """

  # Sort points by x-coordinate, then by y-coordinate
  red_points.sort()
  blue_points.sort()

  # Initialize a list to store the pairs
  pairs = []

  # Iterate through the sorted lists
  blue_index = 0
  for i, red_point in enumerate(red_points):
    while blue_index < len(blue_points) and blue_points[blue_index][1] < red_point[1]:
      blue_index += 1
    if blue_index == len(blue_points):
      return None  # No solution found
    pairs.append((i + 1, blue_index + 1))
    blue_index += 1

  return pairs

# Read input
t = int(input())
for _ in range(t):
  n = int(input())
  blue_points = [tuple(map(int, input().split())) for _ in range(n)]
  red_points = [tuple(map(int, input().split())) for _ in range(n)]

  # Find and print the pairs
  result = connect_points(red_points, blue_points)
  if result:
    for pair in result:
      print(*pair)
  else:
    print(0)