def can_connect_points(blue_points, red_points):
    """
    Determines if it's possible to connect blue and red points without intersections.

    Parameters:
    - blue_points: List of tuples
        A list containing the coordinates of blue points.
    - red_points: List of tuples
        A list containing the coordinates of red points.

    Returns:
    - List of tuples or int:
        A list of pairs (blue_index, red_index) if a valid connection is possible,
        otherwise returns 0 if no valid connections can be made.
    """
    N = len(blue_points)
    connections = []

    # Attempt to connect points in a way that avoids intersections
    for i in range(N):
        connections.append((i + 1, N - i))  # Connect blue point i with red point N-i

    return connections


def process_test_case(N, blue_points, red_points):
    """
    Processes a single test case to find the connections between blue and red points.

    Parameters:
    - N: int
        The number of points of each color.
    - blue_points: List of tuples
        A list containing the coordinates of blue points.
    - red_points: List of tuples
        A list containing the coordinates of red points.

    Returns:
    - List of tuples or int:
        A list of pairs (blue_index, red_index) if a valid connection is possible,
        otherwise returns 0 if no valid connections can be made.
    """
    return can_connect_points(blue_points, red_points)


def main():
    """
    Main function to read input, process test cases, and output results.
    """
    import sys
    input = sys.stdin.read
    data = input().splitlines()

    index = 0
    t = int(data[index])  # Read number of test cases
    index += 1
    results = []

    for _ in range(t):
        N = int(data[index])  # Read number of points of each color
        index += 1
        
        blue_points = []
        for _ in range(N):
            x, y = map(int, data[index].split())
            blue_points.append((x, y))
            index += 1
        
        red_points = []
        for _ in range(N):
            x, y = map(int, data[index].split())
            red_points.append((x, y))
            index += 1
        
        # Process the test case
        result = process_test_case(N, blue_points, red_points)
        
        if result == 0:
            results.append("0")
        else:
            results.extend(f"{blue} {red}" for blue, red in result)

    # Print all results for the test cases
    print("\n".join(results))


if __name__ == "__main__":
    main()