from typing import List, Tuple
 
def connect_points(t: int, test_cases: List[Tuple[int, List[Tuple[int, int]], List[Tuple[int, int]]]]) -> List[List[Tuple[Tuple[int, int], Tuple[int, int]]]]:
    """
    Connects points of different colors (red and blue) without intersections.
 
    Parameters:
    - t: int
        The number of test cases.
    - test_cases: List[Tuple[int, List[Tuple[int, int]], List[Tuple[int, int]]]]
        A list of test cases, where each test case is a tuple containing:
        - N: int
            The number of points of each color.
        - List of blue points as tuples of (x, y).
        - List of red points as tuples of (x, y).
 
    Returns:
    - List[List[Tuple[Tuple[int, int], Tuple[int, int]]]]:
        A list of results for each test case, where each result is a list of tuples,
        each containing a pair of connected points (one blue and one red).
    """
 
    results = []
 
    for case in test_cases:
        N, blue_points, red_points = case
        
        # Sort blue and red points to ensure a consistent pairing
        blue_points.sort()
        red_points.sort()
 
        # Create pairs of connections between blue and red points
        connections = []
        for i in range(N):
            connections.append((blue_points[i], red_points[i]))
 
        results.append(connections)
 
    return results
 
def main():
    """
    Main function to read input and output the connections of points.
    """
 
    import sys
    input = sys.stdin.read
    data = input().splitlines()
 
    index = 0
    t = int(data[index])
    index += 1
    test_cases = []
 
    for _ in range(t):
        N = int(data[index])
        index += 1
        blue_points = []
        red_points = []
 
        for _ in range(N):
            x, y = map(int, data[index].split())
            blue_points.append((x, y))
            index += 1
 
        for _ in range(N):
            x, y = map(int, data[index].split())
            red_points.append((x, y))
            index += 1
 
        test_cases.append((N, blue_points, red_points))
 
    results = connect_points(t, test_cases)
 
    for connections in results:
        for blue, red in connections:
            print(f"{blue[0]} {blue[1]} {red[0]} {red[1]}")
 
if __name__ == "__main__":
    main()