from typing import List, Tuple
from itertools import combinations
import sys

Point = Tuple[int, int]

def orientation(a: Point, b: Point, c: Point) -> int:
    val = (b[1] - a[1]) * (c[0] - b[0]) - (b[0] - a[0]) * (c[1] - b[1])
    return 0 if val == 0 else (1 if val > 0 else 2)

def on_segment(a: Point, b: Point, c: Point) -> bool:
    return (min(a[0], b[0]) <= c[0] <= max(a[0], b[0]) and
            min(a[1], b[1]) <= c[1] <= max(a[1], b[1]))

def segments_intersect(p1: Point, p2: Point, q1: Point, q2: Point) -> bool:
    o1, o2 = orientation(p1, p2, q1), orientation(p1, p2, q2)
    o3, o4 = orientation(q1, q2, p1), orientation(q1, q2, p2)
    return (o1 != o2 and o3 != o4 or
            o1 == 0 and on_segment(p1, p2, q1) or
            o2 == 0 and on_segment(p1, p2, q2) or
            o3 == 0 and on_segment(q1, q2, p1) or
            o4 == 0 and on_segment(q1, q2, p2))

def is_valid(pairings: List[Tuple[int, int]], points: Tuple[List[Point], List[Point]]) -> bool:
    return all(not segments_intersect(points[0][a], points[1][b], points[0][c], points[1][d])
               for (a, b), (c, d) in combinations(pairings, 2))

def backtrack(index: int, pairings: Tuple[Tuple[int, int], ...], points: Tuple[List[Point], List[Point]]) -> Tuple[Tuple[int, int], ...]:
    if index == len(points[0]):
        return pairings

    for j in range(len(points[1])):
        if j not in {b for _, b in pairings}:
            new_pairings = pairings + ((index, j),)
            if is_valid(list(new_pairings), points):
                result = backtrack(index + 1, new_pairings, points)
                if result is not None:
                    return result
    return None

def solve_dot_problem(red_dots: List[Point], blue_dots: List[Point]) -> List[Tuple[int, int]]:
    result = backtrack(0, (), (red_dots, blue_dots))
    return [(j + 1, i + 1) for i, j in result] if result else [0]

def main():
    input_data = sys.stdin.read().strip().split()
    idx = 0
    t = int(input_data[idx])
    idx += 1
    results = []
    
    for _ in range(t):
        N = int(input_data[idx])
        idx += 1
        blue_dots = [tuple(map(int, input_data[idx + i * 2: idx + i * 2 + 2])) for i in range(N)]
        idx += 2 * N
        red_dots = [tuple(map(int, input_data[idx + i * 2: idx + i * 2 + 2])) for i in range(N)]
        idx += 2 * N
        
        solution = solve_dot_problem(red_dots, blue_dots)
        results.append('\n'.join(' '.join(map(str, pair)) for pair in solution))
    
    print('\n'.join(results))

if __name__ == "__main__":
    main()