#include <iostream>
#include <vector>
#include <numeric>
#include <algorithm>

using namespace std;
using ll = long long;

struct Point {
    int x = 0;
    int y = 0;
    int id = -1;
    int color = -1;

    Point operator-(const Point& other) const {
        return { .x = x - other.x, .y = y - other.y, .id = -1, .color = -1 };
    }

    int cross(const Point& other) const {
        return x * other.y - y * other.x;
    }
};

void print_point_list(const vector<Point>& points) {
    for (Point point : points) {
        cout << point.x << " " << point.y << "\n";
    }
}

pair<vector<Point>, vector<Point>> separate_convex_hull(vector<Point>& points) {
    if (points.size() < 4) {
        return { points, {} };
    }

    vector<Point> hull{};
    vector<Point> postponed{};
    vector<Point> rest{};

    sort(points.begin(), points.end(), [&](Point a, Point b) {
        return a.x == b.x ? a.y < b.y : a.x < b.x;
    });

    // vector<Point> part1{};
    // vector<Point> part2{};
    // int threshold_y = points[0].y;

    // for (Point point : points) {
    //     if (point.y >= threshold_y) {
    //         part1.push_back(point);
    //     } else {
    //         part2.push_back(point);
    //     }
    // }

    for (Point& point : points) {
        while (hull.size() >= 2 && (hull.back() - hull[hull.size() - 2]).cross(point - hull[hull.size() - 2]) > 0) {
            postponed.push_back(hull.back());
            hull.pop_back();
        }

        hull.push_back(point);
    }

    reverse(postponed.begin(), postponed.end());
    postponed.push_back(points[0]);

    for (Point& point : postponed) {
        while (hull.size() >= 2 && (hull.back() - hull[hull.size() - 2]).cross(point - hull[hull.size() - 2]) > 0) {
            rest.push_back(hull.back());
            hull.pop_back();
        }

        hull.push_back(point);
    }

    hull.pop_back();

    return { hull, rest };
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    int tests;
    cin >> tests;

    while (tests--) {
        int count;
        cin >> count;

        vector<Point> points{};

        for (int i = 0; i < count; i++) {
            int x, y;
            cin >> x >> y;

            points.push_back({ .x = x, .y = y, .id = i + 1, .color = 0 });
        }

        for (int i = 0; i < count; i++) {
            int x, y;
            cin >> x >> y;

            points.push_back({ .x = x, .y = y, .id = i + 1, .color = 1 });
        }

        vector<Point> curr_points = points;

        while (true) {
            if (curr_points.size() == 0) {
                break;
            }

            auto [hull, rest] = separate_convex_hull(curr_points);

            // cout << "Hull:\n";
            // print_point_list(hull);
            // cout << "Rest:\n";
            // print_point_list(rest);

            bool first_paired = false;
            bool last_paired = false;

            for (int i = 0; i < hull.size() - 1; i++) {
                if (hull[i].color != hull[i + 1].color) {
                    int red_id = hull[i].id;
                    int blue_id = hull[i + 1].id;

                    if (hull[i].color == 1) {
                        swap(red_id, blue_id);
                    }

                    // cout << "* " << red_id << " " << blue_id << "\n";
                    cout << red_id << " " << blue_id << "\n";

                    if (i == 0) {
                        first_paired = true;
                    }

                    if (i + 1 == hull.size() - 1) {
                        last_paired = true;
                    }

                    i += 1;
                } else {
                    rest.push_back(hull[i]);
                }
            }

            if (!first_paired && !last_paired && hull[0].color != hull.back().color) {
                int red_id = hull[0].id;
                int blue_id = hull.back().id;

                if (hull[0].color == 1) {
                    swap(red_id, blue_id);
                }

                // cout << "* " << red_id << " " << blue_id << "\n";
                cout << red_id << " " << blue_id << "\n";

                first_paired = true;
                last_paired = true;
            }

            if (!first_paired) {
                rest.push_back(hull[0]);
            }

            if (!last_paired) {
                rest.push_back(hull.back());
            }

            curr_points = rest;
        }
    }

    return 0;
}
