# Допоміжні функції для перевірки перетину відрізків
def on_segment(p, q, r):
    """Перевіряє, чи точка q знаходиться на відрізку pr"""
    return (q[0] <= max(p[0], r[0]) and q[0] >= min(p[0], r[0]) and
            q[1] <= max(p[1], r[1]) and q[1] >= min(p[1], r[1]))

def orientation(p, q, r):
    """Визначає орієнтацію пари точок"""
    val = (q[1] - p[1]) * (r[0] - q[0]) - (q[0] - p[0]) * (r[1] - q[1])
    if val == 0:
        return 0  # Колінеарні
    return 1 if val > 0 else 2  # 1 - за годинниковою, 2 - проти годинникової

def do_intersect(p1, q1, p2, q2):
    """Перевіряє, чи перетинаються відрізки p1q1 і p2q2"""
    o1 = orientation(p1, q1, p2)
    o2 = orientation(p1, q1, q2)
    o3 = orientation(p2, q2, p1)
    o4 = orientation(p2, q2, q1)
    
    # Загальний випадок
    if o1 != o2 and o3 != o4:
        return True
    
    # Спеціальні випадки для колінеарних точок
    if o1 == 0 and on_segment(p1, p2, q1): return True
    if o2 == 0 and on_segment(p1, q2, q1): return True
    if o3 == 0 and on_segment(p2, p1, q2): return True
    if o4 == 0 and on_segment(p2, q1, q2): return True
    
    return False

# Пошук пари точок
def find_pair(blue_points, red_points, N):
    """Пошук пари точок, де відрізки не перетинаються"""
    used = [False] * N
    result = []
    
    def backtrack(i, current_pairs):
        """Рекурсивний пошук з поверненням"""
        if i == N:
            return current_pairs
        
        for j in range(N):
            if not used[j]:
                # Перевіряємо, чи не буде перетину з поточними парами
                can_add = True
                new_pair = (blue_points[i], red_points[j])
                for p1, q1 in current_pairs:
                    if do_intersect(p1, q1, blue_points[i], red_points[j]):
                        can_add = False
                        break
                if can_add:
                    used[j] = True
                    result = backtrack(i + 1, current_pairs + [new_pair])
                    if result:
                        return result
                    used[j] = False
        
        return None

    return backtrack(0, [])

def solve_case(N, blue_points, red_points):
    result = find_pair(blue_points, red_points, N)
    if result:
        return [(blue_points.index(pair[0]) + 1, red_points.index(pair[1]) + 1) for pair in result]
    else:
        return [0]

def main():
    t = int(input())  # Кількість тестів
    for _ in range(t):
        N = int(input())  # Кількість точок одного кольору
        blue_points = [tuple(map(int, input().split())) for _ in range(N)]
        red_points = [tuple(map(int, input().split())) for _ in range(N)]
        
        result = solve_case(N, blue_points, red_points)
        
        if result == [0]:
            print(0)
        else:
            for pair in result:
                print(f"{pair[0]} {pair[1]}")

if __name__ == "__main__":
    main()
