#include <iostream>
#include <vector>
#include <cmath>
#include <set>
#include <tuple>
using namespace std;

struct Point {
    int x, y, index;
};

double distance(const Point& a, const Point& b) {
    return sqrt((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
}

void solveTestCase(int N, vector<Point>& bluePoints, vector<Point>& redPoints) {
    vector<pair<int, int>> pairs;
    set<int> usedRed; 
    for (const auto& blue : bluePoints) {
        double minDist = 1e9;
        int chosenRed = -1;

        for (const auto& red : redPoints) {
            if (usedRed.count(red.index)) continue;
            double d = distance(blue, red);
            if (d < minDist) {
                minDist = d;
                chosenRed = red.index;
            }
        }

        if (chosenRed == -1) {
            cout << 0;
            return;
        }

        pairs.emplace_back(blue.index, chosenRed);
        usedRed.insert(chosenRed);
    }

    for (const auto& p : pairs) {
        cout << p.first << " " << p.second;
    }
}

int main() {
    int t;
    cin >> t;

    while (t--) {
        int N;
        cin >> N;

        vector<Point> bluePoints(N);
        vector<Point> redPoints(N);

        for (int i = 0; i < N; i++) {
            cin >> bluePoints[i].x >> bluePoints[i].y;
            bluePoints[i].index = i + 1;
        }

        for (int i = 0; i < N; i++) {
            cin >> redPoints[i].x >> redPoints[i].y;
            redPoints[i].index = i + 1;
        }

        solveTestCase(N, bluePoints, redPoints);
    }

    return 0;
}