#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

struct Point {
    int x, y, index, color; // color = 0 (blue), 1 (red)
};

bool segmentsIntersect(Point a, Point b, Point c, Point d) {
    auto cross = [](Point p1, Point p2, Point p3) {
        return (p2.x - p1.x) * (p3.y - p1.y) - (p2.y - p1.y) * (p3.x - p1.x);
    };
    return (cross(a, b, c) * cross(a, b, d) < 0) &&
           (cross(c, d, a) * cross(c, d, b) < 0);
}

int main() {
    int t;
    cin >> t;

    while (t--) {
        int N;
        cin >> N;

        vector<Point> blue(N), red(N);
        for (int i = 0; i < N; ++i) {
            cin >> blue[i].x >> blue[i].y;
            blue[i].index = i + 1;
            blue[i].color = 0;
        }
        for (int i = 0; i < N; ++i) {
            cin >> red[i].x >> red[i].y;
            red[i].index = i + 1;
            red[i].color = 1;
        }

        vector<Point> allPoints = blue;
        allPoints.insert(allPoints.end(), red.begin(), red.end());
        sort(allPoints.begin(), allPoints.end(), [](Point a, Point b) {
            return a.x < b.x || (a.x == b.x && a.y < b.y);
        });

        vector<pair<int, int>> matches;
        vector<bool> usedBlue(N, false), usedRed(N, false);

        for (const auto& point : allPoints) {
            if (point.color == 0) {
                for (int i = 0; i < N; ++i) {
                    if (!usedRed[i]) {
                        matches.emplace_back(point.index, red[i].index);
                        usedBlue[point.index - 1] = true;
                        usedRed[i] = true;
                        break;
                    }
                }
            }
        }

        bool valid = true;
        for (size_t i = 0; i < matches.size(); ++i) {
            for (size_t j = i + 1; j < matches.size(); ++j) {
                Point a = blue[matches[i].first - 1];
                Point b = red[matches[i].second - 1];
                Point c = blue[matches[j].first - 1];
                Point d = red[matches[j].second - 1];
                if (segmentsIntersect(a, b, c, d)) {
                    valid = false;
                    break;
                }
            }
            if (!valid) break;
        }

        if (!valid) {
            cout << 0 << endl;
        } else {
            for (const auto& match : matches) {
                cout << match.first << " " << match.second << endl;
            }
        }
    }

    return 0;
}