#include <iostream>
#include <vector>
#include <cmath>
#include <limits>
#include <algorithm>

struct Point {
    int x, y;
    int index;
};

double distance(const Point& a, const Point& b) {
    return std::sqrt((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
}

std::vector<std::pair<int, int>> solve_case(int N, const std::vector<Point>& blue_points, const std::vector<Point>& red_points) {
    std::vector<std::pair<int, int>> pairs;
    std::vector<bool> used_red(N, false);

    for (int i = 0; i < N; ++i) {
        double min_distance = std::numeric_limits<double>::max();
        int chosen_j = -1;
        for (int j = 0; j < N; ++j) {
            if (!used_red[j]) {
                double dist = distance(blue_points[i], red_points[j]);
                if (dist < min_distance) {
                    min_distance = dist;
                    chosen_j = j;
                }
            }
        }
        pairs.emplace_back(blue_points[i].index, red_points[chosen_j].index);
        used_red[chosen_j] = true;
    }

    return pairs;
}

int main() {
    int t;
    std::cin >> t;

    while (t--) {
        int N;
        std::cin >> N;
        std::vector<Point> blue_points(N), red_points(N);

        for (int i = 0; i < N; ++i) {
            std::cin >> blue_points[i].x >> blue_points[i].y;
            blue_points[i].index = i + 1;
        }

        for (int i = 0; i < N; ++i) {
            std::cin >> red_points[i].x >> red_points[i].y;
            red_points[i].index = i + 1;
        }

        std::vector<std::pair<int, int>> result = solve_case(N, blue_points, red_points);

        for (const auto& pair : result) {
            std::cout << pair.first << " " << pair.second << std::endl;
        }
    }

    return 0;
}
