#include <iostream>
#include <vector>
#include <algorithm>
#include <cmath>

struct Point {
    int x, y;
};

double distance(const Point& a, const Point& b) {
    return std::sqrt((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
}

std::vector<std::pair<int, int>> solve_case(int N, const std::vector<Point>& blue_points, const std::vector<Point>& red_points) {
    std::vector<std::pair<double, std::pair<int, int>>> edges;
    for (int i = 0; i < N; ++i) {
        for (int j = 0; j < N; ++j) {
            edges.push_back({distance(blue_points[i], red_points[j]), {i, j}});
        }
    }

    std::sort(edges.begin(), edges.end());

    std::vector<bool> blue_used(N, false), red_used(N, false);
    std::vector<std::pair<int, int>> pairs;

    for (const auto& edge : edges) {
        int blue = edge.second.first;
        int red = edge.second.second;
        if (!blue_used[blue] && !red_used[red]) {
            pairs.push_back({blue + 1, red + 1});
            blue_used[blue] = true;
            red_used[red] = true;
        }
    }

    if (pairs.size() != N) {
        return {};
    }

    return pairs;
}

int main() {
    int t;
    std::cin >> t;

    while (t--) {
        int N;
        std::cin >> N;
        std::vector<Point> blue_points(N), red_points(N);

        for (int i = 0; i < N; ++i) {
            std::cin >> blue_points[i].x >> blue_points[i].y;
        }

        for (int i = 0; i < N; ++i) {
            std::cin >> red_points[i].x >> red_points[i].y;
        }

        std::vector<std::pair<int, int>> result = solve_case(N, blue_points, red_points);

        if (result.empty()) {
            std::cout << 0 << std::endl;
        } else {
            for (const auto& pair : result) {
                std::cout << pair.first << " " << pair.second << std::endl;
            }
        }
    }

    return 0;
}
