#include <iostream>
#include <vector>
#include <algorithm>

struct Point {
    int x, y;
    int index;
};

bool comparePoints(const Point &a, const Point &b) {
    return a.x < b.x;
}

bool isCrossing(int x1, int y1, int x2, int y2, int x3, int y3, int x4, int y4) {
    auto cross = [](int x1, int y1, int x2, int y2, int x3, int y3) {
        return (x2 - x1) * (y3 - y1) - (y2 - y1) * (x3 - x1);
    };

    return (cross(x1, y1, x2, y2, x3, y3) * cross(x1, y1, x2, y2, x4, y4) < 0) &&
           (cross(x3, y3, x4, y4, x1, y1) * cross(x3, y3, x4, y4, x2, y2) < 0);
}

std::vector<std::pair<int, int>> solve_case(int N, std::vector<Point>& blue_points, std::vector<Point>& red_points) {
    std::vector<std::pair<int, int>> pairs;

    std::sort(blue_points.begin(), blue_points.end(), comparePoints);
    std::sort(red_points.begin(), red_points.end(), comparePoints);

    for (int i = 0; i < N; ++i) {
        pairs.push_back({blue_points[i].index, red_points[i].index});
    }

    for (size_t i = 0; i < pairs.size(); ++i) {
        for (size_t j = i + 1; j < pairs.size(); ++j) {
            if (isCrossing(blue_points[pairs[i].first - 1].x, blue_points[pairs[i].first - 1].y,
                           red_points[pairs[i].second - 1].x, red_points[pairs[i].second - 1].y,
                           blue_points[pairs[j].first - 1].x, blue_points[pairs[j].first - 1].y,
                           red_points[pairs[j].second - 1].x, red_points[pairs[j].second - 1].y)) {
                return {};  // Возвращаем пустой вектор, если найдено пересечение
            }
        }
    }

    return pairs;
}

int main() {
    int t;
    std::cin >> t;

    while (t--) {
        int N;
        std::cin >> N;
        std::vector<Point> blue_points(N);
        std::vector<Point> red_points(N);

        for (int i = 0; i < N; ++i) {
            std::cin >> blue_points[i].x >> blue_points[i].y;
            blue_points[i].index = i + 1;
        }

        for (int i = 0; i < N; ++i) {
            std::cin >> red_points[i].x >> red_points[i].y;
            red_points[i].index = i + 1;
        }

        std::vector<std::pair