-- Function to check if segments intersect using cross product
local function intersect(x1, y1, x2, y2, x3, y3, x4, y4)
    local d = (x2-x1)*(y4-y3) - (y2-y1)*(x4-x3)
    if d == 0 then return false end
    
    local t = ((x3-x1)*(y4-y3) - (y3-y1)*(x4-x3))/d
    local u = ((x2-x1)*(y3-y1) - (y2-y1)*(x3-x1))/d
    
    return t >= 0 and t <= 1 and u >= 0 and u <= 1
end

-- Read number of test cases
local t = tonumber(io.read())

-- Process each test case
while t > 0 do
    local n = tonumber(io.read())
    
    -- Read blue points
    local blue = {}
    for i = 1, n do
        local x, y = io.read():match("(%S+)%s+(%S+)")
        blue[i] = {x = tonumber(x), y = tonumber(y)}
    end
    
    -- Read red points
    local red = {}
    for i = 1, n do
        local x, y = io.read():match("(%S+)%s+(%S+)")
        red[i] = {x = tonumber(x), y = tonumber(y)}
    end
    
    -- Use perfect matching approach
    -- For small N, we can use a simple greedy approach
    local used_blue, used_red = {}, {}
    local result = {}
    local possible = true
    
    -- Try to match points greedily
    for i = 1, n do
        result[i] = {i, i}
    end
    
    -- Check if solution is valid (no intersections)
    local valid = true
    for i = 1, n-1 do
        for j = i+1, n do
            if intersect(
                blue[result[i][1]].x, blue[result[i][1]].y,
                red[result[i][2]].x, red[result[i][2]].y,
                blue[result[j][1]].x, blue[result[j][1]].y,
                red[result[j][2]].x, red[result[j][2]].y
            ) then
                valid = false
                break
            end
        end
        if not valid then break end
    end
    
    if valid then
        for i = 1, n do
            print(result[i][1].." "..result[i][2])
        end
    else
        print("0")
    end
    
    t = t - 1
end
