const scanf = require('scanf');

function doIntersect(x1, y1, x2, y2, x3, y3, x4, y4) {
    function orientation(px, py, qx, qy, rx, ry) {
        let val = (qy - py) * (rx - qx) - (qx - px) * (ry - qy);
        if (val === 0) return 0;
        return (val > 0) ? 1 : 2;
    }
    
    let o1 = orientation(x1, y1, x2, y2, x3, y3);
    let o2 = orientation(x1, y1, x2, y2, x4, y4);
    let o3 = orientation(x3, y3, x4, y4, x1, y1);
    let o4 = orientation(x3, y3, x4, y4, x2, y2);
    
    return (o1 != o2 && o3 != o4);
}

function solve(n, blue, red) {
    let used = new Array(n).fill(false);
    let result = [];
    let connections = [];
    
    function isValidConnection(b, r) {
        let x1 = blue[b][0], y1 = blue[b][1];
        let x2 = red[r][0], y2 = red[r][1];
        
        for(let conn of connections) {
            let x3 = blue[conn[0]][0], y3 = blue[conn[0]][1];
            let x4 = red[conn[1]][0], y4 = red[conn[1]][1];
            if(doIntersect(x1, y1, x2, y2, x3, y3, x4, y4)) {
                return false;
            }
        }
        return true;
    }
    
    function backtrack(blueIdx) {
        if(blueIdx === n) return true;
        
        for(let r = 0; r < n; r++) {
            if(!used[r] && isValidConnection(blueIdx, r)) {
                used[r] = true;
                connections.push([blueIdx, r]);
                result.push([blueIdx + 1, r + 1]);
                
                if(backtrack(blueIdx + 1)) return true;
                
                used[r] = false;
                connections.pop();
                result.pop();
            }
        }
        return false;
    }
    
    if(backtrack(0)) return result;
    return [0];
}

let t = scanf('%d');

for(let i = 0; i < t; i++) {
    let n = scanf('%d');
    let blue = [];
    let red = [];
    
    for(let j = 0; j < n; j++) {
        let [x, y] = [scanf('%d'), scanf('%d')];
        blue.push([x, y]);
    }
    
    for(let j = 0; j < n; j++) {
        let [x, y] = [scanf('%d'), scanf('%d')];
        red.push([x, y]);
    }
    
    let result = solve(n, blue, red);
    
    if(result[0] === 0) {
        console.log(0);
    } else {
        for(let pair of result) {
            console.log(pair[0] + ' ' + pair[1]);
        }
    }
}
