#include <iostream>
#include <vector>
#include <algorithm>
using namespace std;

struct Point {
    int x, y, index;
};

// Функція для перевірки перетину двох відрізків
bool doIntersect(Point a, Point b, Point c, Point d) {
    auto orientation = [](Point p, Point q, Point r) {
        int val = (q.y - p.y) * (r.x - q.x) - (q.x - p.x) * (r.y - q.y);
        if (val == 0) return 0; // Точки лежать на одній прямій
        return (val > 0) ? 1 : 2; // Правий чи лівий поворот
    };

    int o1 = orientation(a, b, c);
    int o2 = orientation(a, b, d);
    int o3 = orientation(c, d, a);
    int o4 = orientation(c, d, b);

    // Перевірка загального перетину
    if (o1 != o2 && o3 != o4) return true;
    return false;
}

int main() {
    int t;
    cin >> t;
    while (t--) {
        int N;
        cin >> N;

        vector<Point> blue(N), red(N);
        for (int i = 0; i < N; ++i) {
            cin >> blue[i].x >> blue[i].y;
            blue[i].index = i + 1; // Індексація з 1
        }
        for (int i = 0; i < N; ++i) {
            cin >> red[i].x >> red[i].y;
            red[i].index = i + 1; // Індексація з 1
        }

        // Сортуємо точки за x і y
        sort(blue.begin(), blue.end(), [](Point a, Point b) {
            return a.x < b.x || (a.x == b.x && a.y < b.y);
        });
        sort(red.begin(), red.end(), [](Point a, Point b) {
            return a.x < b.x || (a.x == b.x && a.y < b.y);
        });

        // Параметр для перевірки перетинів
        bool hasIntersection = false;

        // Перевірка всіх можливих пар відрізків на перетин
        for (int i = 0; i < N; ++i) {
            for (int j = i + 1; j < N; ++j) {
                if (doIntersect(blue[i], red[i], blue[j], red[j])) {
                    hasIntersection = true;
                    break;
                }
            }
            if (hasIntersection) break;
        }

        // Якщо є перетини, вивести 0
        if (hasIntersection) {
            cout << 0 << endl;
        } else {
            // Вивести пари точок, якщо немає перетинів
            for (int i = 0; i < N; ++i) {
                cout << blue[i].index << " " << red[i].index << endl;
            }
        }
    }
    return 0;
}
