#include <bits/stdc++.h>
using namespace std;

struct Point {
    int x;
    int y;
    bool operator<(const Point& other) const {
        if (x != other.x)
            return x < other.x;
        return y < other.y;
    }
};

int main(){
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    
    int N;
    cin >> N;
    
    // Зчитування grid і зберігання точок за кольором
    // grid[y][x], де y від 0 (нижній рядок) до N-1 (верхній рядок)
    vector<vector<int>> grid(N, vector<int>(N, 0));
    for(int y = 0; y < N; ++y){
        for(int x = 0; x < N; ++x){
            cin >> grid[y][x];
        }
    }
    
    // Зберігаємо точки для кожного кольору
    // color_points[0] - сині точки, color_points[1] - червоні точки
    vector<set<Point>> color_points(2, set<Point>());
    for(int y = 0; y < N; ++y){
        for(int x = 0; x < N; ++x){
            int c = grid[y][x];
            color_points[c].insert(Point{x, y});
        }
    }
    
    long long total_squares = 0;
    
    // Функція для підрахунку квадратів для заданого кольору
    auto count_squares = [&](const set<Point>& points) -> long long {
        long long count = 0;
        // Перетворюємо множину в вектор для швидкого доступу
        vector<Point> pts(points.begin(), points.end());
        int M = pts.size();
        // Використовуємо карту для прискорення пошуку точок
        unordered_set<long long> point_set;
        for(auto &p : pts){
            // Кодуємо координати в одне число для зручності
            long long code = (long long)p.x * (N+1) + p.y;
            point_set.insert(code);
        }
        
        // Ітеруємо через всі пари точок
        for(int i = 0; i < M; ++i){
            for(int j = i+1; j < M; ++j){
                // Вектори між точками
                int dx = pts[j].x - pts[i].x;
                int dy = pts[j].y - pts[i].y;
                
                // Обчислюємо координати інших двох точок для першої орієнтації квадрата
                // Поворот вектора (dx, dy) на 90 градусів: (-dy, dx)
                int x3 = pts[j].x - dy;
                int y3 = pts[j].y + dx;
                int x4 = pts[i].x - dy;
                int y4 = pts[i].y + dx;
                
                // Перевіряємо, чи точки знаходяться в межах
                if(x3 >=0 && x3 < N && y3 >=0 && y3 < N && 
                   x4 >=0 && x4 < N && y4 >=0 && y4 < N){
                    // Перевіряємо, чи існують ці точки
                    long long code3 = (long long)x3 * (N+1) + y3;
                    long long code4 = (long long)x4 * (N+1) + y4;
                    if(point_set.find(code3) != point_set.end() && 
                       point_set.find(code4) != point_set.end()){
                           count++;
                    }
                }
                
                // Обчислюємо координати інших двох точок для другої орієнтації квадрата
                // Поворот вектора (dx, dy) на -90 градусів: (dy, -dx)
                int x3_prime = pts[j].x + dy;
                int y3_prime = pts[j].y - dx;
                int x4_prime = pts[i].x + dy;
                int y4_prime = pts[i].y - dx;
                
                // Перевіряємо, чи точки знаходяться в межах
                if(x3_prime >=0 && x3_prime < N && y3_prime >=0 && y3_prime < N && 
                   x4_prime >=0 && x4_prime < N && y4_prime >=0 && y4_prime < N){
                    // Перевіряємо, чи існують ці точки
                    long long code3_p = (long long)x3_prime * (N+1) + y3_prime;
                    long long code4_p = (long long)x4_prime * (N+1) + y4_prime;
                    if(point_set.find(code3_p) != point_set.end() && 
                       point_set.find(code4_p) != point_set.end()){
                           count++;
                    }
                }
            }
        }
        
        // Кожен квадрат рахувався чотири рази (по кожній парі сторін)
        return count / 4;
    };
    
    // Підраховуємо квадрати для кожного кольору
    for(int c = 0; c < 2; ++c){
        total_squares += count_squares(color_points[c]);
    }
    
    cout << total_squares;
    
    return 0;
}