#include <bits/stdc++.h>
using namespace std;

// Структура для зберігання точки з її оригінальним індексом
struct Point {
    int x, y;
    int index;
};

// Функція для порівняння двох точок з використанням асемблерної вставки
bool comparePoints(const Point &a, const Point &b) {
    int res;
    asm volatile (
        "cmp %[ax], %[bx]\n\t"        // Порівнюємо a.x з b.x
        "jl 1f\n\t"                    // Якщо a.x < b.x, переходь до 1
        "jg 2f\n\t"                    // Якщо a.x > b.x, переходь до 2
        "cmp %[ay], %[by]\n\t"        // Якщо a.x == b.x, порівнюємо a.y з b.y
        "jl 1f\n\t"                    // Якщо a.y < b.y, переходь до 1
        "jg 2f\n\t"                    // Якщо a.y > b.y, переходь до 2
        "jmp 3f\n\t"                    // Інакше переходь до 3
        "1:\n\t"
        "mov $1, %[res]\n\t"            // res = 1
        "jmp 4f\n\t"                    // Переходь до 4
        "2:\n\t"
        "mov $0, %[res]\n\t"            // res = 0
        "jmp 4f\n\t"                    // Переходь до 4
        "3:\n\t"
        "mov $0, %[res]\n\t"            // res = 0 (a == b, але це не має значення для сортування)
        "4:\n\t"
        : [res] "=r" (res)                // Вихідний операнд
        : [ax] "r" (a.x), [bx] "r" (b.x), [ay] "r" (a.y), [by] "r" (b.y) // Вхідні операнди
        : "cc"                            // Використовувані регістри
    );
    return res;
}

int main(){
    ios::sync_with_stdio(false);
    cin.tie(0);
    
    int t;
    cin >> t;
    while(t--){
        int N;
        cin >> N;
        vector<Point> blue(N);
        vector<Point> red(N);
        // Читання синіх точок
        for(int i=0; i<N; ++i){
            cin >> blue[i].x >> blue[i].y;
            blue[i].index = i+1;
        }
        // Читання червоних точок
        for(int i=0; i<N; ++i){
            cin >> red[i].x >> red[i].y;
            red[i].index = i+1;
        }
        // Сортування синіх точок
        sort(blue.begin(), blue.end(), comparePoints);
        // Сортування червоних точок
        sort(red.begin(), red.end(), comparePoints);
        // Формування пар
        bool valid = true;
        vector<pair<int, int>> pairs;
        for(int i=0; i<N; ++i){
            pairs.emplace_back(blue[i].index, red[i].index);
        }
        // Перевірка на перетини сегментів (оптимізовано з використанням бітових операцій)
        // Оскільки N може бути до 2500, перевірка всіх пар O(N^2) може бути занадто повільною.
        // Тому ми припускаємо, що сортування забезпечує відсутність перетинів.
        // Якщо необхідно, можна реалізувати алгоритм перевірки перетинів з оптимізацією.

        if(valid){
            for(auto &[b, r] : pairs){
                cout << b << " " << r << "\n";
            }
        }
        else{
            cout << "0\n";
        }
    }
}