#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

// Структура для зберігання координат точки
struct Point {
    int x, y, index;
};

// Функція для обчислення орієнтації трійки точок
// Оповідає, в якому напрямку знаходяться три точки
int orientation(Point p, Point q, Point r) {
    int val = (q.y - p.y) * (r.x - q.x) - (q.x - p.x) * (r.y - q.y);
    if (val == 0) return 0; // точки колінійні
    return (val > 0) ? 1 : 2; // 1 = за годинниковою стрілкою, 2 = проти годинникової
}

// Функція для перевірки, чи перетинаються два відрізки
bool doIntersect(Point p1, Point q1, Point p2, Point q2) {
    int o1 = orientation(p1, q1, p2);
    int o2 = orientation(p1, q1, q2);
    int o3 = orientation(p2, q2, p1);
    int o4 = orientation(p2, q2, q1);

    // Загальний випадок
    if (o1 != o2 && o3 != o4) return true;

    // Спеціальні випадки: перевіряємо, чи лежать точки на відрізках
    return false;
}

int main() {
    int t;
    cin >> t;

    while (t--) {
        int N;
        cin >> N;

        vector<Point> blue(N), red(N);

        for (int i = 0; i < N; ++i) {
            cin >> blue[i].x >> blue[i].y;
            blue[i].index = i + 1;
        }

        for (int i = 0; i < N; ++i) {
            cin >> red[i].x >> red[i].y;
            red[i].index = i + 1;
        }

        // Перевіряємо кожне можливе з'єднання
        vector<pair<int, int>> result;

        // Перевірка для можливості з'єднання без перетинів
        bool possible = true;
        for (int i = 0; i < N; ++i) {
            for (int j = i + 1; j < N; ++j) {
                // Перевірка, чи відрізки не перетинаються
                if (doIntersect(blue[i], red[i], blue[j], red[j])) {
                    possible = false;
                    break;
                }
            }
            if (!possible) break;
        }

        if (possible) {
            for (int i = 0; i < N; ++i) {
                cout << blue[i].index << " " << red[i].index << endl;
            }
        } else {
            cout << "0" << endl;
        }
    }

    return 0;
}
