#include <iostream>
#include <vector>
#include <algorithm>

using namespace std;

struct Point {
    int x, y;
};

// Функція для обчислення квадрата відстані між двома точками
int distSq(Point p1, Point p2) {
    return (p1.x - p2.x) * (p1.x - p2.x) +
           (p1.y - p2.y) * (p1.y - p2.y);
}

// Функція для знаходження орієнтації трьох точок
int orientation(Point p, Point q, Point r) {
    int val = (q.y - p.y) * (r.x - q.x) -
              (q.x - p.x) * (r.y - q.y);
    if (val == 0) return 0;  // Колінеарні
    return (val > 0) ? 1 : 2; // 1 для проти годинникової, 2 для годинникової
}

// Функція для сортування точок за полярним кутом відносно p0
bool compare(Point p1, Point p2, Point p0) {
    int o = orientation(p0, p1, p2);
    if (o == 0)
        return (distSq(p0, p2) >= distSq(p0, p1));
    return (o == 2);
}

// Функція для знаходження опуклої оболонки
vector<Point> convexHull(vector<Point> points) {
    int n = points.size();
    if (n < 3) return {};

    // Знаходимо точку з найменшою y-координатою
    int ymin = points[0].y, min = 0;
    for (int i = 1; i < n; i++) {
        int y = points[i].y;
        if ((y < ymin) || (ymin == y && points[i].x < points[min].x))
            ymin = points[i].y, min = i;
    }

    // Поміняємо найменшу точку з першою
    swap(points[0], points[min]);

    // Сортуємо точки за полярним кутом відносно першої точки
    Point p0 = points[0];
    sort(points.begin() + 1, points.end(),
         [&](const Point &p1, const Point &p2) {
             return compare(p0, p1, p2);
         });

    // Будуємо опуклу оболонку
    vector<Point> hull;
    hull.push_back(points[0]);
    hull.push_back(points[1]);
    for (int i = 2; i < n; i++) {
        while (hull.size() >= 2 && orientation(hull[hull.size() - 2], hull[hull.size() - 1], points[i]) != 2)
            hull.pop_back();
        hull.push_back(points[i]);
    }

    return hull;
}

int main() {
    int n;
    cin >> n;

    vector<Point> blue_points(n);
    vector<Point> red_points(n);

    // Зчитування координат точок
    for (int i = 0; i < n; ++i) {
        cin >> blue_points[i].x >> blue_points[i].y;
    }
    for (int i = 0; i < n; ++i) {
        cin >> red_points[i].x >> red_points[i].y;
    }

    // Знаходження опуклих оболонок
    vector<Point> blue_hull = convexHull(blue_points);
    vector<Point> red_hull = convexHull(red_points);

    // Обробка вироджених випадків
    if (blue_hull.size() < 3 || red_hull.size() < 3) {
        cout << "Всі точки лежать на одній прямій" << endl;
        return 0;
    }

    // З'єднання точок
    int i = 0, j = 0;
    while (i < blue_hull.size() && j < red_hull.size()) {
        cout << blue_hull[i].x << " " << blue_hull[i].y << " "
             << red_hull[j].x << " " << red_hull[j].y << endl;
        i = (i + 1) % blue_hull.size();
        j = (j + 1) % red_hull.size();
    }

    return 0;
}