#include <iostream>
#include <vector>
#include <cmath>
#include <algorithm>
#include <set>

using namespace std;

struct Point {
    int x, y;
};

double distance(Point a, Point b) {
    return sqrt((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
}

bool isIntersecting(Point a, Point b, Point c, Point d) {
    auto orientation = [](Point p, Point q, Point r) {
        int val = (q.y - p.y) * (r.x - q.x) - (q.x - p.x) * (r.y - q.y);
        if (val == 0) return 0;
        return (val > 0) ? 1 : 2;
    };

    int o1 = orientation(a, b, c);
    int o2 = orientation(a, b, d);
    int o3 = orientation(c, d, a);
    int o4 = orientation(c, d, b);

    if (o1 != o2 && o3 != o4) return true;

    return false;
}

bool isValid(Point b1, Point r1, vector<pair<Point, Point>>& connections) {
    for (const auto& conn : connections) {
        if (isIntersecting(b1, r1, conn.first, conn.second)) {
            return false;
        }
    }
    return true;
}

bool solve() {
    int N;
    cin >> N;

    vector<Point> blue(N), red(N);
    for (int i = 0; i < N; ++i) {
        cin >> blue[i].x >> blue[i].y;
    }
    for (int i = 0; i < N; ++i) {
        cin >> red[i].x >> red[i].y;
    }

    vector<pair<Point, Point>> connections;
    vector<bool> blue_used(N, false), red_used(N, false);
    vector<pair<int, int>> result;

    for (int i = 0; i < N; ++i) {
        int best_red = -1;
        double min_dist = 1e9;

        for (int j = 0; j < N; ++j) {
            if (red_used[j]) continue;

            double dist = distance(blue[i], red[j]);
            if (dist < min_dist && isValid(blue[i], red[j], connections)) {
                min_dist = dist;
                best_red = j;
            }
        }

        if (best_red == -1) {
            cout << "0" << endl;
            return false;
        }

        connections.push_back({blue[i], red[best_red]});
        result.push_back({i + 1, best_red + 1});
        red_used[best_red] = true;
    }

    for (const auto& p : result) {
        cout << p.first << " " << p.second << endl;
    }

    return true;
}

int main() {
    int t;
    cin >> t;

    while (t--) {
        if (!solve()) {
            cout << "0" << endl;
        }
    }

    return 0;
}