#include <iostream>
#include <vector>
#include <algorithm>
#include <cmath> // Для atan2
#include <climits> // Для INT_MAX

using namespace std;

struct Point {
    int x, y, color; // color: 0 - blue, 1 - red
};

// Функція для обчислення векторного добутку (перехресного добутку)
int crossProduct(const Point &a, const Point &b) {
    return a.x * b.y - a.y * b.x;
}

// Функція для перевірки перетину відрізків
bool intersect(const Point &p1, const Point &p2, const Point &q1, const Point &q2) {
    Point p1q1 = {q1.x - p1.x, q1.y - p1.y};
    Point p1q2 = {q2.x - p1.x, q2.y - p1.y};
    Point p1p2 = {p2.x - p1.x, p2.y - p1.y};
    Point q1p1 = {-p1q1.x, -p1q1.y};
    Point q1p2 = {-p1p2.x, -p1p2.y};

    int d1 = crossProduct(p1q1, p1p2);
    int d2 = crossProduct(p1q2, p1p2);
    int d3 = crossProduct(q1p1, q1p2);
    int d4 = crossProduct(q1p2, q1p1);

    return (d1 * d2 < 0 && d3 * d4 < 0);
}

// Функція порівняння точок для сортування за кутом
bool cmp(const Point &a, const Point &b, int minX, int minY) {
    return atan2(a.y - minY, a.x - minX) < atan2(b.y - minY, b.x - minX);
}

int main() {
    int t;
    cin >> t;

    while (t--) {
        int n;
        cin >> n;

        vector<Point> points(2 * n);
        int minX = INT_MAX, minY = INT_MAX;

        for (int i = 0; i < 2 * n; ++i) {
            cin >> points[i].x >> points[i].y;
            points[i].color = i < n ? 0 : 1; // Сині точки - color 0, червоні - color 1
            minX = min(minX, points[i].x);
            minY = min(minY, points[i].y);
        }

        // Сортуємо точки за кутом
        sort(points.begin(), points.end(), [&](const Point &a, const Point &b) {
            return cmp(a, b, minX, minY);
        });

        vector<int> pairs(n);
        int lastColor = points[0].color;
        int lastIndex = 0;

        for (int i = 1; i < 2 * n; ++i) {
            if (points[i].color != lastColor) {
                pairs[lastIndex] = i;
                lastIndex = i;
                lastColor = points[i].color;
            } else {
                // Перевірка на перетин відрізків
                if (intersect(points[lastIndex], points[i], points[pairs[lastIndex]], points[pairs[i]])) {
                    cout << 0 << endl;
                    break;
                }
            }
        }

        // Виведення результату
        if (lastIndex == 2 * n - 1) {
            for (int i = 0; i < n; ++i) {
                cout << pairs[i] + 1 << " " << pairs[i + n] + 1 << endl;
            }
        }
    }

    return 0;
}
