def orientation(p, q, r):
    """Return the orientation of the triplet (p, q, r).
    0 -> p, q and r are collinear
    1 -> Clockwise
    2 -> Counterclockwise
    """
    val = (q[1] - p[1]) * (r[0] - q[0]) - (q[0] - p[0]) * (r[1] - q[1])
    if val == 0:
        return 0
    elif val > 0:
        return 1
    else:
        return 2

def do_intersect(p1, q1, p2, q2):
    """Check if line segment 'p1q1' and 'p2q2' intersect."""
    o1 = orientation(p1, q1, p2)
    o2 = orientation(p1, q1, q2)
    o3 = orientation(p2, q2, p1)
    o4 = orientation(p2, q2, q1)

    # General case
    if o1 != o2 and o3 != o4:
        return True

    # Special cases
    # p1, q1 and p2 are collinear and p2 lies on segment p1q1
    if o1 == 0 and on_segment(p1, p2, q1):
        return True

    # p1, q1 and q2 are collinear and q2 lies on segment p1q1
    if o2 == 0 and on_segment(p1, q2, q1):
        return True

    # p2, q2 and p1 are collinear and p1 lies on segment p2q2
    if o3 == 0 and on_segment(p2, p1, q2):
        return True

    # p2, q2 and q1 are collinear and q1 lies on segment p2q2
    if o4 == 0 and on_segment(p2, q1, q2):
        return True

    return False

def on_segment(p, q, r):
    """Check if point q lies on line segment 'pr'."""
    if (q[0] <= max(p[0], r[0]) and q[0] >= min(p[0], r[0]) and
            q[1] <= max(p[1], r[1]) and q[1] >= min(p[1], r[1])):
        return True
    return False

def solve_case(N, blue_points, red_points):
    # Sort points by x-coordinate
    blue_points_sorted = sorted(blue_points)
    red_points_sorted = sorted(red_points)

    # Pair points
    pairs = []
    for i in range(N):
        pairs.append((blue_points_sorted[i], red_points_sorted[i]))

    # Check for intersections
    for i in range(N):
        for j in range(i + 1, N):
            if do_intersect(pairs[i][0], pairs[i][1], pairs[j][0], pairs[j][1]):
                return 0

    # If no intersections, return the pairs
    result = []
    for i in range(N):
        blue_index = blue_points.index(pairs[i][0]) + 1
        red_index = red_points.index(pairs[i][1]) + 1
        result.append((blue_index, red_index))
    return result

def main():
    import sys
    input = sys.stdin.read
    data = input().split()
    
    index = 0
    t = int(data[index])
    index += 1
    results = []
    
    for _ in range(t):
        N = int(data[index])
        index += 1
        blue_points = []
        red_points = []
        
        for _ in range(N):
            x = int(data[index])
            y = int(data[index + 1])
            blue_points.append((x, y))
            index += 2
        
        for _ in range(N):
            x = int(data[index])
            y = int(data[index + 1])
            red_points.append((x, y))
            index += 2
        
        result = solve_case(N, blue_points, red_points)
        results.append(result)
    
    for result in results:
        if result == 0:
            print(0)
        else:
            for pair in result:
                print(pair[0], pair[1])

if __name__ == "__main__":
    main()