def does_intersect(p1, p2, q1, q2):
    def orientation(a, b, c):
        val = (b[1] - a[1]) * (c[0] - b[0]) - (b[0] - a[0]) * (c[1] - b[1])
        if val == 0: return 0
        return 1 if val > 0 else -1

    o1 = orientation(p1, p2, q1)
    o2 = orientation(p1, p2, q2)
    o3 = orientation(q1, q2, p1)
    o4 = orientation(q1, q2, p2)

    if o1 != o2 and o3 != o4:
        return True
    return False

def solve_single_test(n, blue_points, red_points):
    blue_points = sorted((x, y, i + 1) for i, (x, y) in enumerate(blue_points))
    red_points = sorted((x, y, i + 1) for i, (x, y) in enumerate(red_points))

    pairs = []
    used_segments = []

    for i in range(n):
        b_point = blue_points[i]
        r_point = red_points[i]
        
        for (b, r) in used_segments:
            if does_intersect(b_point[:2], r_point[:2], b[:2], r[:2]):
                return [0]

        pairs.append((b_point[2], r_point[2]))
        used_segments.append((b_point, r_point))

    return pairs

def main():
    import sys
    input = sys.stdin.read
    data = input().splitlines()
    
    t = int(data[0])
    results = []
    idx = 1

    for _ in range(t):
        n = int(data[idx])
        idx += 1

        blue_points = [tuple(map(int, data[idx + i].split())) for i in range(n)]
        red_points = [tuple(map(int, data[idx + n + i].split())) for i in range(n)]
        idx += 2 * n

        result = solve_single_test(n, blue_points, red_points)
        results.append(result)

    output = []
    for result in results:
        if result == [0]:
            output.append("0")
        else:
            output.extend(f"{b} {r}" for b, r in result)
            output.append("")
    print("\n".join(output))

if __name__ == "__main__":
    main()
