#include <iostream>
#include <vector>
#include <algorithm>
using namespace std;

struct Point {
    int x, y;
    int index; 
};

struct Segment {
    int blue, red;
};

bool intersect(Point& p1, Point& p2, Point& p3, Point& p4) {
    auto orientation = [](Point& p, Point& q, Point& r) {
        int val = (q.y - p.y) * (r.x - q.x) - (q.x - p.x) * (r.y - q.y);
        if (val == 0) return 0;
        return (val > 0) ? 1 : 2;
    };

    auto onSegment = [](Point& p, Point& q, Point& r) {
        return (p.x <= max(q.x, r.x) && p.x >= min(q.x, r.x) &&
                p.y <= max(q.y, r.y) && p.y >= min(q.y, r.y));
    };

    int o1 = orientation(p1, p2, p3);
    int o2 = orientation(p1, p2, p4);
    int o3 = orientation(p3, p4, p1);
    int o4 = orientation(p3, p4, p2);

    if (o1 != o2 && o3 != o4) return true;

    if (o1 == 0 && onSegment(p3, p1, p2)) return true;
    if (o2 == 0 && onSegment(p4, p1, p2)) return true;
    if (o3 == 0 && onSegment(p1, p3, p4)) return true;
    if (o4 == 0 && onSegment(p2, p3, p4)) return true;

    return false;
}

bool isValidSegment(vector<Segment>& segments, vector<Point>& blue, vector<Point>& red, 
                   int blueIdx, int redIdx) {
    Point& newBlue = blue[blueIdx - 1];
    Point& newRed = red[redIdx - 1];
    
    for(const auto& seg : segments) {
        if(intersect(blue[seg.blue - 1], red[seg.red - 1], newBlue, newRed)) {
            return false;
        }
    }
    return true;
}

void solve() {
    int N;
    cin >> N;
    
    vector<Point> blue(N);
    for(int i = 0; i < N; i++) {
        cin >> blue[i].x >> blue[i].y;
        blue[i].index = i + 1;
    }
    
    vector<Point> red(N);
    for(int i = 0; i < N; i++) {
        cin >> red[i].x >> red[i].y;
        red[i].index = i + 1;
    }
    
    vector<bool> usedBlue(N + 1, false);
    vector<bool> usedRed(N + 1, false);
    vector<Segment> segments;
    
    for(int i = 1; i <= N; i++) {
        if(usedBlue[i]) continue;
        
        for(int j = 1; j <= N; j++) {
            if(usedRed[j]) continue;
            
            if(isValidSegment(segments, blue, red, i, j)) {
                segments.push_back({i, j});
                usedBlue[i] = true;
                usedRed[j] = true;
                break;
            }
        }
    }
    
    if(segments.size() == N) {
        for(const auto& seg : segments) {
            cout << seg.blue << " " << seg.red << "\n";
        }
    } else {
        cout << "0\n";
    }
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);
    
    int t;
    cin >> t;
    while(t--) {
        solve();
    }
    return 0;
}