#include <iostream>
#include <vector>
#include <algorithm>
#include <cmath>
using namespace std;

bool ccw(pair<int, int> a, pair<int, int> b, pair<int, int> c) {
    return (c.second - a.second) * (b.first - a.first) > (b.second - a.second) * (c.first - a.first);
}

bool intersect(pair<int, int> a, pair<int, int> b, pair<int, int> c, pair<int, int> d) {
    return ccw(a, c, d) != ccw(b, c, d) && ccw(a, b, c) != ccw(a, b, d);
}

vector<string> solve_matching(int n, vector<pair<int, int>>& blue_points, vector<pair<int, int>>& red_points) {
    vector<int> perm(n);
    for (int i = 0; i < n; ++i) perm[i] = i;

    do {
        bool valid = true;
        vector<pair<pair<int, int>, pair<int, int>>> used_edges;

        for (int blue_idx = 0; blue_idx < n; ++blue_idx) {
            pair<pair<int, int>, pair<int, int>> edge = 
                {{blue_points[blue_idx].first, blue_points[blue_idx].second}, 
                 {red_points[perm[blue_idx]].first, red_points[perm[blue_idx]].second}};

            for (const auto& prev_edge : used_edges) {
                if (intersect(edge.first, edge.second, prev_edge.first, prev_edge.second)) {
                    valid = false;
                    break;
                }
            }

            if (!valid) break;
            used_edges.push_back(edge);
        }

        if (valid) {
            vector<string> result;
            for (int blue_idx = 0; blue_idx < n; ++blue_idx) {
                result.push_back(to_string(blue_idx + 1) + " " + to_string(perm[blue_idx] + 1));
            }
            return result;
        }
    } while (next_permutation(perm.begin(), perm.end()));

    return {"0"};
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    int t;
    cin >> t;

    while (t--) {
        int n;
        cin >> n;

        vector<pair<int, int>> blue_points(n);
        vector<pair<int, int>> red_points(n);

        for (int i = 0; i < n; ++i) {
            cin >> blue_points[i].first >> blue_points[i].second;
        }

        for (int i = 0; i < n; ++i) {
            cin >> red_points[i].first >> red_points[i].second;
        }

        vector<string> result = solve_matching(n, blue_points, red_points);

        for (const string& line : result) {
            cout << line << '\n';
        }
    }

    return 0;
}