#include <iostream>
#include <vector>
#include <algorithm>
#include <cmath>

using namespace std;

struct Point {
    int x, y, idx;
};

struct Edge {
    int u, v;
};

bool intersect(const Point& a, const Point& b, const Point& c, const Point& d) {
    auto ccw = [](const Point& a, const Point& b, const Point& c) {
        long long cross = 1LL * (b.x - a.x) * (c.y - a.y) - 1LL * (b.y - a.y) * (c.x - a.x);
        return cross > 0 ? 1 : (cross < 0 ? -1 : 0);
    };

    return (ccw(a, c, d) * ccw(b, c, d) <= 0) && 
           (ccw(c, a, b) * ccw(d, a, b) <= 0);
}

vector<int> kuhn_matching(int n, const vector<Point>& blue, const vector<Point>& red) {
    vector<vector<int>> graph(n);
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < n; ++j) {
            bool can_connect = true;
            for (int k = 0; k < n; ++k) {
                if (k != i && k != j) {
                    if (intersect(blue[i], red[j], blue[k], red[k])) {
                        can_connect = false;
                        break;
                    }
                }
            }
            if (can_connect) {
                graph[i].push_back(j);
            }
        }
    }

    vector<int> match(n, -1);
    vector<bool> used(n, false);

    function<bool(int)> try_kuhn = [&](int v) {
        if (used[v]) return false;
        used[v] = true;
        for (int u : graph[v]) {
            if (match[u] == -1 || try_kuhn(match[u])) {
                match[u] = v;
                return true;
            }
        }
        return false;
    };

    for (int v = 0; v < n; ++v) {
        used.assign(n, false);
        try_kuhn(v);
    }

    return match;
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    int t;
    cin >> t;

    while (t--) {
        int n;
        cin >> n;

        vector<Point> blue(n), red(n);

        for (int i = 0; i < n; ++i) {
            cin >> blue[i].x >> blue[i].y;
            blue[i].idx = i + 1;
        }

        for (int i = 0; i < n; ++i) {
            cin >> red[i].x >> red[i].y;
            red[i].idx = i + 1;
        }

        vector<int> match = kuhn_matching(n, blue, red);

        bool has_solution = true;
        for (int i = 0; i < n; ++i) {
            if (match[i] == -1) {
                has_solution = false;
                break;
            }
        }

        if (!has_solution) {
            cout << "0\n";
        } else {
            for (int i = 0; i < n; ++i) {
                cout << blue[match[i]].idx << " " << red[i].idx << "\n";
            }
        }
    }

    return 0;
}