#include <iostream>
#include <vector>
#include <algorithm>
#include <cmath>
#include <functional>

using namespace std;

struct Point {
    int x, y, idx;
};

vector<int> kuhn_matching(int n, const vector<Point>& blue, const vector<Point>& red) {
    vector<vector<int>> graph(n);
    for (int i = 0; i < n; ++i) {
        for (int j = 0; j < n; ++j) {
            bool can_connect = true;
            for (int k = 0; k < n; ++k) {
                if (k != i && k != j) {
                    long long cross1 = 1LL * (red[j].x - blue[i].x) * (blue[k].y - blue[i].y) 
                                      - 1LL * (red[j].y - blue[i].y) * (blue[k].x - blue[i].x);
                    long long cross2 = 1LL * (red[j].x - blue[i].x) * (red[k].y - blue[i].y) 
                                      - 1LL * (red[j].y - blue[i].y) * (red[k].x - blue[i].x);
                    
                    if ((cross1 == 0 && cross2 == 0) || 
                        (cross1 * cross2 <= 0 && 
                         1LL * (blue[k].x - blue[i].x) * (red[k].y - blue[i].y) 
                        != 1LL * (blue[k].y - blue[i].y) * (red[k].x - blue[i].x))) {
                        can_connect = false;
                        break;
                    }
                }
            }
            if (can_connect) {
                graph[i].push_back(j);
            }
        }
    }

    vector<int> match(n, -1);
    vector<bool> used(n);

    function<bool(int)> dfs = [&](int v) -> bool {
        if (used[v]) return false;
        used[v] = true;
        for (int u : graph[v]) {
            if (match[u] == -1 || dfs(match[u])) {
                match[u] = v;
                return true;
            }
        }
        return false;
    };

    for (int v = 0; v < n; ++v) {
        used.assign(n, false);
        dfs(v);
    }

    return match;
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    int t;
    cin >> t;

    while (t--) {
        int n;
        cin >> n;

        vector<Point> blue(n), red(n);

        for (int i = 0; i < n; ++i) {
            cin >> blue[i].x >> blue[i].y;
            blue[i].idx = i + 1;
        }

        for (int i = 0; i < n; ++i) {
            cin >> red[i].x >> red[i].y;
            red[i].idx = i + 1;
        }

        vector<int> match = kuhn_matching(n, blue, red);

        bool has_solution = true;
        for (int i = 0; i < n; ++i) {
            if (match[i] == -1) {
                has_solution = false;
                break;
            }
        }

        if (!has_solution) {
            cout << "0\n";
        } else {
            for (int i = 0; i < n; ++i) {
                cout << blue[match[i]].idx << " " << red[i].idx << "\n";
            }
        }
    }

    return 0;
}