#include <iostream>
#include <vector>
#include <algorithm>
#include <cmath>

using namespace std;

struct Point {
    int x, y, idx;
};

bool ccw(Point a, Point b, Point c) {
    return 1LL * (b.x - a.x) * (c.y - a.y) > 1LL * (b.y - a.y) * (c.x - a.x);
}

bool intersect(Point a, Point b, Point c, Point d) {
    return ccw(a, c, d) != ccw(b, c, d) && ccw(a, b, c) != ccw(a, b, d);
}

vector<int> solve(int n, vector<Point>& blue, vector<Point>& red) {
    vector<pair<int, int>> order(n);
    for (int i = 0; i < n; ++i) order[i] = {red[i].x + red[i].y, i};
    sort(order.begin(), order.end());

    vector<int> used_red(n, 0);
    vector<int> match(n, -1);

    for (int i = 0; i < n; ++i) {
        int best_j = -1;
        for (int j = 0; j < n; ++j) {
            if (used_red[j]) continue;

            bool valid = true;
            for (int k = 0; k < i; ++k) {
                if (match[k] != -1 && 
                    intersect(blue[i], red[order[j].second], 
                              blue[k], red[match[k]])) {
                    valid = false;
                    break;
                }
            }

            if (valid) {
                best_j = j;
                break;
            }
        }

        if (best_j == -1) return {};
        match[i] = order[best_j].second;
        used_red[best_j] = 1;
    }

    return match;
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    int t;
    cin >> t;

    while (t--) {
        int n;
        cin >> n;

        vector<Point> blue(n), red(n);

        for (int i = 0; i < n; ++i) {
            cin >> blue[i].x >> blue[i].y;
            blue[i].idx = i + 1;
        }

        for (int i = 0; i < n; ++i) {
            cin >> red[i].x >> red[i].y;
            red[i].idx = i + 1;
        }

        vector<int> match = solve(n, blue, red);

        if (match.empty()) {
            cout << "0\n";
        } else {
            for (int i = 0; i < n; ++i) {
                cout << blue[i].idx << " " << red[match[i]].idx << "\n";
            }
        }
    }

    return 0;
}