#include <iostream>
#include <vector>
#include <algorithm>
#include <cmath>

using namespace std;

struct Point {
    int x, y, idx;
};

long long cross_product(const Point& a, const Point& b, const Point& c) {
    return 1LL * (b.x - a.x) * (c.y - a.y) - 1LL * (b.y - a.y) * (c.x - a.x);
}

bool intersect(const Point& a, const Point& b, const Point& c, const Point& d) {
    long long c1 = cross_product(a, b, c);
    long long c2 = cross_product(a, b, d);
    long long c3 = cross_product(c, d, a);
    long long c4 = cross_product(c, d, b);

    if (c1 == 0 && c2 == 0 && c3 == 0 && c4 == 0) return false;

    return (c1 * c2 <= 0) && (c3 * c4 <= 0);
}

vector<int> solve(int n, const vector<Point>& blue, const vector<Point>& red) {
    vector<int> match(n);
    vector<bool> used_red(n, false);

    for (int i = 0; i < n; ++i) {
        bool found_match = false;
        for (int j = 0; j < n; ++j) {
            if (used_red[j]) continue;

            bool valid = true;
            for (int k = 0; k < i; ++k) {
                if (intersect(blue[i], red[j], blue[k], red[match[k]])) {
                    valid = false;
                    break;
                }
            }

            if (valid) {
                match[i] = j;
                used_red[j] = true;
                found_match = true;
                break;
            }
        }

        if (!found_match) return {};
    }

    return match;
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(nullptr);

    int t;
    cin >> t;

    while (t--) {
        int n;
        cin >> n;

        vector<Point> blue(n), red(n);

        for (int i = 0; i < n; ++i) {
            cin >> blue[i].x >> blue[i].y;
            blue[i].idx = i + 1;
        }

        for (int i = 0; i < n; ++i) {
            cin >> red[i].x >> red[i].y;
            red[i].idx = i + 1;
        }

        vector<int> match = solve(n, blue, red);

        if (match.empty()) {
            cout << "0\n";
        } else {
            for (int i = 0; i < n; ++i) {
                cout << blue[i].idx << " " << red[match[i]].idx << "\n";
            }
        }
    }

    return 0;
}