#include <iostream>
#include <vector>
#include <cmath>
#include <algorithm>

struct Point {
    int x, y, index;
    Point(int x, int y, int index) : x(x), y(y), index(index) {}
};

double angleFromCentroid(const Point &p, const Point &centroid) {
    return atan2(p.y - centroid.y, p.x - centroid.x);
}

Point findCentroid(const std::vector<Point> &points) {
    int sumX = 0, sumY = 0;
    for (const auto &p : points) {
        sumX += p.x;
        sumY += p.y;
    }
    return Point(sumX / points.size(), sumY / points.size(), -1);
}

int main() {
    int t;
    std::cin >> t;

    while (t--) {
        int N;
        std::cin >> N;

        std::vector<Point> bluePoints, redPoints;
        for (int i = 0; i < N; ++i) {
            int x, y;
            std::cin >> x >> y;
            bluePoints.emplace_back(x, y, i + 1);
        }

        for (int i = 0; i < N; ++i) {
            int x, y;
            std::cin >> x >> y;
            redPoints.emplace_back(x, y, i + 1);
        }

        Point blueCentroid = findCentroid(bluePoints);
        Point redCentroid = findCentroid(redPoints);

        std::sort(bluePoints.begin(), bluePoints.end(), 
            [&blueCentroid](const Point &a, const Point &b) {
                return angleFromCentroid(a, blueCentroid) < angleFromCentroid(b, blueCentroid);
            }
        );

        std::sort(redPoints.begin(), redPoints.end(), 
            [&redCentroid](const Point &a, const Point &b) {
                return angleFromCentroid(a, redCentroid) < angleFromCentroid(b, redCentroid);
            }
        );

        std::vector<std::pair<int, int>> result;
        for (int i = 0; i < N; ++i) {
            result.emplace_back(bluePoints[i].index, redPoints[i].index);
        }

        for (const auto &pair : result) {
            std::cout << pair.first << " " << pair.second << std::endl;
        }
    }

    return 0;
}
