#include <iostream>
#include <vector>
#include <cmath>
#include <algorithm>

struct Point {
    int x, y, index;
    Point(int x, int y, int index) : x(x), y(y), index(index) {}
};

double distance(const Point &a, const Point &b) {
    return sqrt((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
}

int main() {
    int t;
    std::cin >> t;

    while (t--) {
        int N;
        std::cin >> N;

        std::vector<Point> bluePoints, redPoints;
        for (int i = 0; i < N; ++i) {
            int x, y;
            std::cin >> x >> y;
            bluePoints.emplace_back(x, y, i + 1);
        }

        for (int i = 0; i < N; ++i) {
            int x, y;
            std::cin >> x >> y;
            redPoints.emplace_back(x, y, i + 1);
        }

        std::vector<std::pair<int, int>> matches;
        std::vector<bool> blueMatched(N, false), redMatched(N, false);
        
        for (int i = 0; i < N; ++i) {
            int bestRedIndex = -1;
            double bestDistance = std::numeric_limits<double>::max();
            
            for (int j = 0; j < N; ++j) {
                if (redMatched[j]) continue;
                
                double dist = distance(bluePoints[i], redPoints[j]);
                if (dist < bestDistance) {
                    bestDistance = dist;
                    bestRedIndex = j;
                }
            }
            
            if (bestRedIndex != -1) {
                matches.emplace_back(bluePoints[i].index, redPoints[bestRedIndex].index);
                blueMatched[i] = true;
                redMatched[bestRedIndex] = true;
            }
        }

        if (matches.size() == N) {
            for (const auto &pair : matches) {
                std::cout << pair.first << " " << pair.second << std::endl;
            }
        } else {
            std::cout << 0 << std::endl;
        }
    }

    return 0;
}
