#include <iostream>
#include <vector>
#include <cmath>
#include <limits>
#include <algorithm>

struct Point {
    int x, y, index;
    Point(int x, int y, int index) : x(x), y(y), index(index) {}
};

double distance(const Point &a, const Point &b) {
    return sqrt((a.x - b.x) * (a.x - b.x) + (a.y - b.y) * (a.y - b.y));
}

void assignPoints(const std::vector<Point> &bluePoints, const std::vector<Point> &redPoints, int N) {
    std::vector<std::vector<double>> cost(N, std::vector<double>(N));
    for (int i = 0; i < N; ++i) {
        for (int j = 0; j < N; ++j) {
            cost[i][j] = distance(bluePoints[i], redPoints[j]);
        }
    }

    std::vector<int> u(N+1, 0), v(N+1, 0), p(N+1, 0), way(N+1, 0);
    for (int i = 1; i <= N; ++i) {
        std::vector<int> minv(N+1, std::numeric_limits<int>::max());
        std::vector<bool> used(N+1, false);
        int j0 = 0;
        p[0] = i;
        do {
            used[j0] = true;
            int i0 = p[j0], delta = std::numeric_limits<int>::max(), j1 = 0;
            for (int j = 1; j <= N; ++j) {
                if (!used[j]) {
                    double cur = cost[i0 - 1][j - 1] - u[i0] - v[j];
                    if (cur < minv[j]) {
                        minv[j] = cur;
                        way[j] = j0;
                    }
                    if (minv[j] < delta) {
                        delta = minv[j];
                        j1 = j;
                    }
                }
            }
            for (int j = 0; j <= N; ++j) {
                if (used[j]) {
                    u[p[j]] += delta;
                    v[j] -= delta;
                } else {
                    minv[j] -= delta;
                }
            }
            j0 = j1;
        } while (p[j0] != 0);

        do {
            int j1 = way[j0];
            p[j0] = p[j1];
            j0 = j1;
        } while (j0);
    }

    std::vector<std::pair<int, int>> result(N);
    for (int j = 1; j <= N; ++j) {
        result[p[j] - 1] = {j, p[j]};
    }

    for (const auto &pair : result) {
        std::cout << pair.first << " " << pair.second << std::endl;
    }
}

int main() {
    int t;
    std::cin >> t;

    while (t--) {
        int N;
        std::cin >> N;

        std::vector<Point> bluePoints, redPoints;
        for (int i = 0; i < N; ++i) {
            int x, y;
            std::cin >> x >> y;
            bluePoints.emplace_back(x, y, i + 1);
        }

        for (int i = 0; i < N; ++i) {
            int x, y;
            std::cin >> x >> y;
            redPoints.emplace_back(x, y, i + 1);
        }

        if (N == 0) {
            std::cout << 0 << std::endl;
            continue;
        }

        assignPoints(bluePoints, redPoints, N);
    }

    return 0;
}
