#include <iostream>
#include <vector>
#include <cmath>
#include <algorithm>

struct Point {
    int x, y, index;
    Point(int x, int y, int index) : x(x), y(y), index(index) {}
};

bool compareByAngle(const Point &a, const Point &b) {
    return atan2(a.y, a.x) < atan2(b.y, b.x);
}

bool checkIntersect(Point p1, Point p2, Point p3, Point p4) {
    auto orientation = [](Point a, Point b, Point c) {
        int val = (b.y - a.y) * (c.x - b.x) - (b.x - a.x) * (c.y - b.y);
        if (val == 0) return 0; 
        return (val > 0) ? 1 : 2;
    };

    int o1 = orientation(p1, p2, p3);
    int o2 = orientation(p1, p2, p4);
    int o3 = orientation(p3, p4, p1);
    int o4 = orientation(p3, p4, p2);

    if (o1 != o2 && o3 != o4) return true;

    return false;
}

int main() {
    int t;
    std::cin >> t;

    while (t--) {
        int N;
        std::cin >> N;

        std::vector<Point> bluePoints, redPoints;
        for (int i = 0; i < N; ++i) {
            int x, y;
            std::cin >> x >> y;
            bluePoints.emplace_back(x, y, i + 1);
        }

        for (int i = 0; i < N; ++i) {
            int x, y;
            std::cin >> x >> y;
            redPoints.emplace_back(x, y, i + 1);
        }

        std::sort(bluePoints.begin(), bluePoints.end(), compareByAngle);
        std::sort(redPoints.begin(), redPoints.end(), compareByAngle);

        std::vector<std::pair<int, int>> result;
        bool intersected = false;

        for (int i = 0; i < N; ++i) {
            for (int j = i + 1; j < N; ++j) {
                if (checkIntersect(bluePoints[i], redPoints[i], bluePoints[j], redPoints[j])) {
                    intersected = true;
                    break;
                }
            }
            if (intersected) break;
            result.emplace_back(bluePoints[i].index, redPoints[i].index);
        }

        if (intersected) {
            std::cout << 0 << std::endl;
        } else {
            for (const auto &pair : result) {
                std::cout << pair.first << " " << pair.second << std::endl;
            }
        }
    }

    return 0;
}
