#include <iostream>
#include <vector>
#include <cmath>
#include <algorithm>

struct Point {
    int x, y, index;
    Point(int x, int y, int index) : x(x), y(y), index(index) {}
};

struct Segment {
    Point p1, p2;
    Segment(Point p1, Point p2) : p1(p1), p2(p2) {}
};

bool comparePoints(const Point &a, const Point &b) {
    return a.y < b.y || (a.y == b.y && a.x < b.x);
}

bool doIntersect(Segment s1, Segment s2) {
    auto orientation = [](Point p, Point q, Point r) {
        int val = (q.y - p.y) * (r.x - q.x) - (q.x - p.x) * (r.y - q.y);
        if (val == 0) return 0;
        return (val > 0) ? 1 : 2;
    };

    int o1 = orientation(s1.p1, s1.p2, s2.p1);
    int o2 = orientation(s1.p1, s1.p2, s2.p2);
    int o3 = orientation(s2.p1, s2.p2, s1.p1);
    int o4 = orientation(s2.p1, s2.p2, s1.p2);

    if (o1 != o2 && o3 != o4) return true;

    return false;
}

int main() {
    int t;
    std::cin >> t;

    while (t--) {
        int N;
        std::cin >> N;

        std::vector<Point> bluePoints, redPoints;
        for (int i = 0; i < N; ++i) {
            int x, y;
            std::cin >> x >> y;
            bluePoints.emplace_back(x, y, i + 1);
        }

        for (int i = 0; i < N; ++i) {
            int x, y;
            std::cin >> x >> y;
            redPoints.emplace_back(x, y, i + 1);
        }

        std::sort(bluePoints.begin(), bluePoints.end(), comparePoints);
        std::sort(redPoints.begin(), redPoints.end(), comparePoints);

        std::vector<Segment> segments;
        for (int i = 0; i < N; ++i) {
            segments.emplace_back(bluePoints[i], redPoints[i]);
        }

        bool valid = true;
        for (int i = 0; i < N && valid; ++i) {
            for (int j = i + 1; j < N; ++j) {
                if (doIntersect(segments[i], segments[j])) {
                    valid = false;
                    break;
                }
            }
        }

        if (valid) {
            for (const auto &segment : segments) {
                std::cout << segment.p1.index << " " << segment.p2.index << std::endl;
            }
        } else {
            std::cout << 0 << std::endl;
        }
    }

    return 0;
}
