#include <iostream>
#include <vector>
#include <algorithm>
#include <cmath>

using namespace std;

struct Point {
    int x, y, id;
};

bool compare_x(Point a, Point b) {
    return a.x < b.x || (a.x == b.x && a.y < b.y);
}

bool check_intersection(Point a1, Point a2, Point b1, Point b2) {
    auto cross = [](Point p1, Point p2, Point p3) {
        return (p2.x - p1.x) * (p3.y - p1.y) - (p3.x - p1.x) * (p2.y - p1.y);
    };
    return cross(a1, a2, b1) * cross(a1, a2, b2) < 0 &&
           cross(b1, b2, a1) * cross(b1, b2, a2) < 0;
}

int main() {
    ios::sync_with_stdio(false);
    cin.tie(nullptr);
    int t;
    cin >> t;
    while (t--) {
        int n;
        cin >> n;
        vector<Point> blue(n), red(n);
        for (int i = 0; i < n; i++) {
            cin >> blue[i].x >> blue[i].y;
            blue[i].id = i + 1;
        }
        for (int i = 0; i < n; i++) {
            cin >> red[i].x >> red[i].y;
            red[i].id = i + 1;
        }
        sort(blue.begin(), blue.end(), compare_x);
        sort(red.begin(), red.end(), compare_x);
        vector<pair<int, int>> result;
        bool possible = true;
        for (int i = 0; i < n; i++) result.emplace_back(blue[i].id, red[i].id);
        for (int i = 0; i < n && possible; i++) {
            for (int j = i + 1; j < n; j++) {
                if (check_intersection(blue[i], red[i], blue[j], red[j])) {
                    possible = false;
                    break;
                }
            }
        }
        if (possible) {
            for (auto p : result) cout << p.first << " " << p.second << "\n";
        } else {
            cout << "0\n";
        }
    }
    return 0;
}