#include <iostream>
#include <vector>
#include <algorithm>

struct Point {
    int x, y, index;
    Point(int x, int y, int index) : x(x), y(y), index(index) {}
};

bool compareByX(const Point &a, const Point &b) {
    return a.x < b.x;
}

bool compareByY(const Point &a, const Point &b) {
    return a.y < b.y;
}

bool doIntersect(Point p1, Point p2, Point p3, Point p4) {
    auto orientation = [](Point p, Point q, Point r) {
        int val = (q.y - p.y) * (r.x - q.x) - (q.x - p.x) * (r.y - q.y);
        if (val == 0) return 0;
        return (val > 0) ? 1 : 2;
    };

    int o1 = orientation(p1, p2, p3);
    int o2 = orientation(p1, p2, p4);
    int o3 = orientation(p3, p4, p1);
    int o4 = orientation(p3, p4, p2);

    if (o1 != o2 && o3 != o4) return true;
    return false;
}

int main() {
    int t;
    std::cin >> t;

    while (t--) {
        int N;
        std::cin >> N;

        std::vector<Point> bluePoints, redPoints;
        for (int i = 0; i < N; ++i) {
            int x, y;
            std::cin >> x >> y;
            bluePoints.emplace_back(x, y, i + 1);
        }

        for (int i = 0; i < N; ++i) {
            int x, y;
            std::cin >> x >> y;
            redPoints.emplace_back(x, y, i + 1);
        }

        std::sort(bluePoints.begin(), bluePoints.end(), compareByX);
        std::sort(redPoints.begin(), redPoints.end(), compareByX);

        std::vector<std::pair<int, int>> pairs;
        bool valid = true;

        for (int i = 0; i < N; ++i) {
            pairs.emplace_back(bluePoints[i].index, redPoints[i].index);
        }

        for (int i = 0; i < N - 1; ++i) {
            for (int j = i + 1; j < N; ++j) {
                if (doIntersect(bluePoints[i], redPoints[i], bluePoints[j], redPoints[j])) {
                    valid = false;
                    break;
                }
            }
            if (!valid) break;
        }

        if (valid) {
            for (const auto &pair : pairs) {
                std::cout << pair.first << " " << pair.second << std::endl;
            }
        } else {
            std::cout << 0 << std::endl;
        }
    }

    return 0;
}